<?php
// This file was auto-generated from sdk-root/src/data/ssm/2014-11-06/docs-2.json
return [ 'version' => '2.0', 'service' => '<p>This is the Amazon Simple Systems Manager (SSM) API Reference. SSM enables you to remotely manage the configuration of your Amazon EC2 instance using scripts or commands with either an on-demand solution called <i>SSM Run Command</i> or a lightweight instance configuration solution called <i>SSM Config</i>. </p> <p>This references is intended to be used with the SSM User Guide for <a href="http://docs.aws.amazon.com/AWSEC2/latest/UserGuide/execute-remote-commands.html">Linux</a> or <a href="http://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/execute-remote-commands.html">Windows</a>.</p> <p> <b>Run Command</b> </p> <p>Run Command provides an on-demand experience for executing commands. You can use pre-defined Amazon SSM documents to perform the actions listed later in this section, or you can create your own documents. With these documents, you can remotely configure your instances by sending commands using the <b>Commands</b> page in the <a href="http://console.aws.amazon.com/ec2/">Amazon EC2 console</a>, <a href="http://docs.aws.amazon.com/powershell/latest/reference/items/Amazon_Simple_Systems_Management_cmdlets.html">AWS Tools for Windows PowerShell</a>, the <a href="http://docs.aws.amazon.com/cli/latest/reference/ssm/index.html">AWS CLI</a>, or AWS SDKs.</p> <p>Run Command reports the status of the command execution for each instance targeted by a command. You can also audit the command execution to understand who executed commands, when, and what changes were made. By switching between different SSM documents, you can quickly configure your instances with different types of commands. To get started with Run Command, verify that your environment meets the prerequisites for remotely running commands on EC2 instances (<a href="http://docs.aws.amazon.com/AWSEC2/latest/UserGuide/remote-commands-prereq.html">Linux</a> or <a href="http://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/remote-commands-prereq.html">Windows</a>). </p> <p/> <p> <b>SSM Config</b> </p> <p>SSM Config is a lightweight instance configuration solution. SSM Config is currently only available for Windows instances. With SSM Config, you can specify a setup configuration for your instances. SSM Config is similar to EC2 User Data, which is another way of running one-time scripts or applying settings during instance launch. SSM Config is an extension of this capability. Using SSM documents, you can specify which actions the system should perform on your instances, including which applications to install, which AWS Directory Service directory to join, which Microsoft PowerShell modules to install, etc. If an instance is missing one or more of these configurations, the system makes those changes. By default, the system checks every five minutes to see if there is a new configuration to apply as defined in a new SSM document. If so, the system updates the instances accordingly. In this way, you can remotely maintain a consistent configuration baseline on your instances. SSM Config is available using the AWS CLI or the AWS Tools for Windows PowerShell. For more information, see <a href="http://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2-configuration-manage.html">Managing Windows Instance Configuration</a>.</p> <p>SSM Config and SSM Run Command include the following pre-defined documents.</p> <p> <b>Linux</b> </p> <ul> <li> <p> <b>AWS-RunShellScript</b> to run shell scripts</p> </li> <li> <p> <b>AWS-UpdateSSMAgent</b> to update the Amazon SSM agent</p> </li> </ul> <p/> <p> <b>Windows</b> </p> <ul> <li> <p> <b>AWS-JoinDirectoryServiceDomain</b> to join an AWS Directory</p> </li> <li> <p> <b>AWS-RunPowerShellScript</b> to run PowerShell commands or scripts</p> </li> <li> <p> <b>AWS-UpdateEC2Config</b> to update the EC2Config service</p> </li> <li> <p> <b>AWS-ConfigureWindowsUpdate</b> to configure Windows Update settings</p> </li> <li> <p> <b>AWS-InstallApplication</b> to install, repair, or uninstall software using an MSI package</p> </li> <li> <p> <b>AWS-InstallPowerShellModule</b> to install PowerShell modules </p> </li> <li> <p> <b>AWS-ConfigureCloudWatch</b> to configure Amazon CloudWatch Logs to monitor applications and systems</p> </li> <li> <p> <b>AWS-ListWindowsInventory</b> to collect information about an EC2 instance running in Windows.</p> </li> <li> <p> <b>AWS-FindWindowsUpdates</b> to scan an instance and determines which updates are missing.</p> </li> <li> <p> <b>AWS-InstallMissingWindowsUpdates</b> to install missing updates on your EC2 instance.</p> </li> <li> <p> <b>AWS-InstallSpecificWindowsUpdates</b> to install one or more specific updates.</p> </li> </ul> <important> <p>The commands or scripts specified in SSM documents run with administrative privilege on your instances because the Amazon SSM agent runs as root on Linux and the EC2Config service runs in the Local System account on Windows. If a user has permission to execute any of the pre-defined SSM documents (any document that begins with AWS-*) then that user also has administrator access to the instance. Delegate access to SSM and Run Command judiciously. This becomes extremely important if you create your own SSM documents. Amazon Web Services does not provide guidance about how to create secure SSM documents. You create SSM documents and delegate access to Run Command at your own risk. As a security best practice, we recommend that you assign access to "AWS-*" documents, especially the AWS-RunShellScript document on Linux and the AWS-RunPowerShellScript document on Windows, to trusted administrators only. You can create SSM documents for specific tasks and delegate access to non-administrators.</p> </important> <p>For information about creating and sharing SSM documents, see the following topics in the SSM User Guide: </p> <ul> <li> <p> <a href="http://docs.aws.amazon.com/AWSEC2/latest/UserGuide/create-ssm-doc.html">Creating SSM Documents</a> and <a href="http://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ssm-sharing.html">Sharing SSM Documents</a> (Linux)</p> </li> <li> <p> <a href="http://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/create-ssm-doc.html">Creating SSM Documents</a> and <a href="http://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ssm-sharing.html">Sharing SSM Documents</a> (Windows)</p> </li> </ul>', 'operations' => [ 'CancelCommand' => '<p>Attempts to cancel the command specified by the Command ID. There is no guarantee that the command will be terminated and the underlying process stopped.</p>', 'CreateAssociation' => '<p>Associates the specified SSM document with the specified instance.</p> <p>When you associate an SSM document with an instance, the configuration agent on the instance processes the document and configures the instance as specified.</p> <p>If you associate a document with an instance that already has an associated document, the system throws the AssociationAlreadyExists exception.</p>', 'CreateAssociationBatch' => '<p>Associates the specified SSM document with the specified instances.</p> <p>When you associate an SSM document with an instance, the configuration agent on the instance processes the document and configures the instance as specified.</p> <p>If you associate a document with an instance that already has an associated document, the system throws the AssociationAlreadyExists exception.</p>', 'CreateDocument' => '<p>Creates an SSM document.</p> <p>After you create an SSM document, you can use CreateAssociation to associate it with one or more running instances.</p>', 'DeleteAssociation' => '<p>Disassociates the specified SSM document from the specified instance.</p> <p>When you disassociate an SSM document from an instance, it does not change the configuration of the instance. To change the configuration state of an instance after you disassociate a document, you must create a new document with the desired configuration and associate it with the instance.</p>', 'DeleteDocument' => '<p>Deletes the SSM document and all instance associations to the document.</p> <p>Before you delete the SSM document, we recommend that you use DeleteAssociation to disassociate all instances that are associated with the document.</p>', 'DescribeAssociation' => '<p>Describes the associations for the specified SSM document or instance.</p>', 'DescribeDocument' => '<p>Describes the specified SSM document.</p>', 'DescribeDocumentPermission' => '<p>Describes the permissions for an SSM document. If you created the document, you are the owner. If a document is shared, it can either be shared privately (by specifying a user’s AWS account ID) or publicly (<i>All</i>). </p>', 'DescribeInstanceInformation' => '<p>Describes one or more of your instances. You can use this to get information about instances like the operating system platform, the SSM agent version, status etc. If you specify one or more instance IDs, it returns information for those instances. If you do not specify instance IDs, it returns information for all your instances. If you specify an instance ID that is not valid or an instance that you do not own, you receive an error. </p>', 'GetDocument' => '<p>Gets the contents of the specified SSM document.</p>', 'ListAssociations' => '<p>Lists the associations for the specified SSM document or instance.</p>', 'ListCommandInvocations' => '<p>An invocation is copy of a command sent to a specific instance. A command can apply to one or more instances. A command invocation applies to one instance. For example, if a user executes SendCommand against three instances, then a command invocation is created for each requested instance ID. ListCommandInvocations provide status about command execution.</p>', 'ListCommands' => '<p>Lists the commands requested by users of the AWS account.</p>', 'ListDocuments' => '<p>Describes one or more of your SSM documents.</p>', 'ModifyDocumentPermission' => '<p>Share a document publicly or privately. If you share a document privately, you must specify the AWS user account IDs for those people who can use the document. If you share a document publicly, you must specify <i>All</i> as the account ID.</p>', 'SendCommand' => '<p>Executes commands on one or more remote instances.</p>', 'UpdateAssociationStatus' => '<p>Updates the status of the SSM document associated with the specified instance.</p>', ], 'shapes' => [ 'AccountId' => [ 'base' => NULL, 'refs' => [ 'AccountIdList$member' => NULL, ], ], 'AccountIdList' => [ 'base' => NULL, 'refs' => [ 'DescribeDocumentPermissionResponse$AccountIds' => '<p>The account IDs that have permission to use this document. The ID can be either an AWS account or <i>All</i>.</p>', 'ModifyDocumentPermissionRequest$AccountIdsToAdd' => '<p>The AWS user accounts that should have access to the document. The account IDs can either be a group of account IDs or <i>All</i>.</p>', 'ModifyDocumentPermissionRequest$AccountIdsToRemove' => '<p>The AWS user accounts that should no longer have access to the document. The AWS user account can either be a group of account IDs or <i>All</i>. This action has a higher priority than <i>AccountIdsToAdd</i>. If you specify an account ID to add and the same ID to remove, the system removes access to the document.</p>', ], ], 'AssociatedInstances' => [ 'base' => '<p>You must disassociate an SSM document from all instances before you can delete it.</p>', 'refs' => [], ], 'Association' => [ 'base' => '<p>Describes an association of an SSM document and an instance.</p>', 'refs' => [ 'AssociationList$member' => NULL, ], ], 'AssociationAlreadyExists' => [ 'base' => '<p>The specified association already exists.</p>', 'refs' => [], ], 'AssociationDescription' => [ 'base' => '<p>Describes the parameters for a document.</p>', 'refs' => [ 'AssociationDescriptionList$member' => NULL, 'CreateAssociationResult$AssociationDescription' => '<p>Information about the association.</p>', 'DescribeAssociationResult$AssociationDescription' => '<p>Information about the association.</p>', 'UpdateAssociationStatusResult$AssociationDescription' => '<p>Information about the association.</p>', ], ], 'AssociationDescriptionList' => [ 'base' => NULL, 'refs' => [ 'CreateAssociationBatchResult$Successful' => '<p>Information about the associations that succeeded.</p>', ], ], 'AssociationDoesNotExist' => [ 'base' => '<p>The specified association does not exist.</p>', 'refs' => [], ], 'AssociationFilter' => [ 'base' => '<p>Describes a filter.</p>', 'refs' => [ 'AssociationFilterList$member' => NULL, ], ], 'AssociationFilterKey' => [ 'base' => NULL, 'refs' => [ 'AssociationFilter$key' => '<p>The name of the filter.</p>', ], ], 'AssociationFilterList' => [ 'base' => NULL, 'refs' => [ 'ListAssociationsRequest$AssociationFilterList' => '<p>One or more filters. Use a filter to return a more specific list of results.</p>', ], ], 'AssociationFilterValue' => [ 'base' => NULL, 'refs' => [ 'AssociationFilter$value' => '<p>The filter value.</p>', ], ], 'AssociationLimitExceeded' => [ 'base' => '<p>You can have at most 2,000 active associations.</p>', 'refs' => [], ], 'AssociationList' => [ 'base' => NULL, 'refs' => [ 'ListAssociationsResult$Associations' => '<p>The associations.</p>', ], ], 'AssociationStatus' => [ 'base' => '<p>Describes an association status.</p>', 'refs' => [ 'AssociationDescription$Status' => '<p>The association status.</p>', 'UpdateAssociationStatusRequest$AssociationStatus' => '<p>The association status.</p>', ], ], 'AssociationStatusName' => [ 'base' => NULL, 'refs' => [ 'AssociationStatus$Name' => '<p>The status.</p>', ], ], 'BatchErrorMessage' => [ 'base' => NULL, 'refs' => [ 'FailedCreateAssociation$Message' => '<p>A description of the failure.</p>', ], ], 'Boolean' => [ 'base' => NULL, 'refs' => [ 'InstanceInformation$IsLatestVersion' => '<p>Indicates whether latest version of the SSM agent is running on your instance. </p>', 'ListCommandInvocationsRequest$Details' => '<p>(Optional) If set this returns the response of the command executions and any command output. By default this is set to False. </p>', ], ], 'CancelCommandRequest' => [ 'base' => '<p/>', 'refs' => [], ], 'CancelCommandResult' => [ 'base' => '<p>Whether or not the command was successfully canceled. There is no guarantee that a request can be canceled.</p>', 'refs' => [], ], 'Command' => [ 'base' => '<p>Describes a command request.</p>', 'refs' => [ 'CommandList$member' => NULL, 'SendCommandResult$Command' => '<p>The request as it was received by SSM. Also provides the command ID which can be used future references to this request.</p>', ], ], 'CommandFilter' => [ 'base' => '<p>Describes a command filter.</p>', 'refs' => [ 'CommandFilterList$member' => NULL, ], ], 'CommandFilterKey' => [ 'base' => NULL, 'refs' => [ 'CommandFilter$key' => '<p>The name of the filter. For example, requested date and time.</p>', ], ], 'CommandFilterList' => [ 'base' => NULL, 'refs' => [ 'ListCommandInvocationsRequest$Filters' => '<p>(Optional) One or more filters. Use a filter to return a more specific list of results.</p>', 'ListCommandsRequest$Filters' => '<p>(Optional) One or more filters. Use a filter to return a more specific list of results. </p>', ], ], 'CommandFilterValue' => [ 'base' => NULL, 'refs' => [ 'CommandFilter$value' => '<p>The filter value. For example: June 30, 2015.</p>', ], ], 'CommandId' => [ 'base' => NULL, 'refs' => [ 'CancelCommandRequest$CommandId' => '<p>The ID of the command you want to cancel.</p>', 'Command$CommandId' => '<p>A unique identifier for this command.</p>', 'CommandInvocation$CommandId' => '<p>The command against which this invocation was requested.</p>', 'ListCommandInvocationsRequest$CommandId' => '<p>(Optional) The invocations for a specific command ID.</p>', 'ListCommandsRequest$CommandId' => '<p>(Optional) If provided, lists only the specified command.</p>', ], ], 'CommandInvocation' => [ 'base' => '<p>An invocation is copy of a command sent to a specific instance. A command can apply to one or more instances. A command invocation applies to one instance. For example, if a user executes SendCommand against three instances, then a command invocation is created for each requested instance ID. A command invocation returns status and detail information about a command you executed. </p>', 'refs' => [ 'CommandInvocationList$member' => NULL, ], ], 'CommandInvocationList' => [ 'base' => NULL, 'refs' => [ 'ListCommandInvocationsResult$CommandInvocations' => '<p>(Optional) A list of all invocations. </p>', ], ], 'CommandInvocationStatus' => [ 'base' => NULL, 'refs' => [ 'CommandInvocation$Status' => '<p>Whether or not the invocation succeeded, failed, or is pending.</p>', ], ], 'CommandList' => [ 'base' => NULL, 'refs' => [ 'ListCommandsResult$Commands' => '<p>(Optional) The list of commands requested by the user. </p>', ], ], 'CommandMaxResults' => [ 'base' => NULL, 'refs' => [ 'ListCommandInvocationsRequest$MaxResults' => '<p>(Optional) The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.</p>', 'ListCommandsRequest$MaxResults' => '<p>(Optional) The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.</p>', ], ], 'CommandPlugin' => [ 'base' => '<p>Describes plugin details.</p>', 'refs' => [ 'CommandPluginList$member' => NULL, ], ], 'CommandPluginList' => [ 'base' => NULL, 'refs' => [ 'CommandInvocation$CommandPlugins' => NULL, ], ], 'CommandPluginName' => [ 'base' => NULL, 'refs' => [ 'CommandPlugin$Name' => '<p>The name of the plugin. Must be one of the following: aws:updateAgent, aws:domainjoin, aws:applications, aws:runPowerShellScript, aws:psmodule, aws:cloudWatch, aws:runShellScript, or aws:updateSSMAgent. </p>', ], ], 'CommandPluginOutput' => [ 'base' => NULL, 'refs' => [ 'CommandPlugin$Output' => '<p>Output of the plugin execution.</p>', ], ], 'CommandPluginStatus' => [ 'base' => NULL, 'refs' => [ 'CommandPlugin$Status' => '<p>The status of this plugin. You can execute a document with multiple plugins.</p>', ], ], 'CommandStatus' => [ 'base' => NULL, 'refs' => [ 'Command$Status' => '<p>The status of the command.</p>', ], ], 'Comment' => [ 'base' => NULL, 'refs' => [ 'Command$Comment' => '<p>User-specified information about the command, such as a brief description of what the command should do.</p>', 'CommandInvocation$Comment' => '<p>User-specified information about the command, such as a brief description of what the command should do.</p>', 'SendCommandRequest$Comment' => '<p>User-specified information about the command, such as a brief description of what the command should do.</p>', ], ], 'CreateAssociationBatchRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateAssociationBatchRequestEntries' => [ 'base' => NULL, 'refs' => [ 'CreateAssociationBatchRequest$Entries' => '<p>One or more associations.</p>', ], ], 'CreateAssociationBatchRequestEntry' => [ 'base' => '<p> Describes the association of an SSM document and an instance. </p>', 'refs' => [ 'CreateAssociationBatchRequestEntries$member' => NULL, 'FailedCreateAssociation$Entry' => '<p>The association.</p>', ], ], 'CreateAssociationBatchResult' => [ 'base' => NULL, 'refs' => [], ], 'CreateAssociationRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateAssociationResult' => [ 'base' => NULL, 'refs' => [], ], 'CreateDocumentRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateDocumentResult' => [ 'base' => NULL, 'refs' => [], ], 'DateTime' => [ 'base' => NULL, 'refs' => [ 'AssociationDescription$Date' => '<p>The date when the association was made.</p>', 'AssociationStatus$Date' => '<p>The date when the status changed.</p>', 'Command$ExpiresAfter' => '<p>If this time is reached and the command has not already started executing, it will not execute. Calculated based on the ExpiresAfter user input provided as part of the SendCommand API.</p>', 'Command$RequestedDateTime' => '<p>The date and time the command was requested.</p>', 'CommandInvocation$RequestedDateTime' => '<p>The time and date the request was sent to this instance.</p>', 'CommandPlugin$ResponseStartDateTime' => '<p>The time the plugin started executing. </p>', 'CommandPlugin$ResponseFinishDateTime' => '<p>The time the plugin stopped executing. Could stop prematurely if, for example, a cancel command was sent. </p>', 'DocumentDescription$CreatedDate' => '<p> The date when the SSM document was created. </p>', 'InstanceInformation$LastPingDateTime' => '<p>The date and time when agent last pinged SSM service. </p>', ], ], 'DeleteAssociationRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteAssociationResult' => [ 'base' => NULL, 'refs' => [], ], 'DeleteDocumentRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteDocumentResult' => [ 'base' => NULL, 'refs' => [], ], 'DescribeAssociationRequest' => [ 'base' => NULL, 'refs' => [], ], 'DescribeAssociationResult' => [ 'base' => NULL, 'refs' => [], ], 'DescribeDocumentPermissionRequest' => [ 'base' => NULL, 'refs' => [], ], 'DescribeDocumentPermissionResponse' => [ 'base' => NULL, 'refs' => [], ], 'DescribeDocumentRequest' => [ 'base' => NULL, 'refs' => [], ], 'DescribeDocumentResult' => [ 'base' => NULL, 'refs' => [], ], 'DescribeInstanceInformationRequest' => [ 'base' => NULL, 'refs' => [], ], 'DescribeInstanceInformationResult' => [ 'base' => NULL, 'refs' => [], ], 'DescriptionInDocument' => [ 'base' => NULL, 'refs' => [ 'DocumentDescription$Description' => '<p> A description of the document. </p>', ], ], 'DocumentARN' => [ 'base' => NULL, 'refs' => [ 'DescribeDocumentRequest$Name' => '<p>The name of the SSM document.</p>', 'DocumentDescription$Name' => '<p>The name of the SSM document.</p>', 'DocumentIdentifier$Name' => '<p>The name of the SSM document.</p>', 'GetDocumentRequest$Name' => '<p>The name of the SSM document.</p>', 'GetDocumentResult$Name' => '<p>The name of the SSM document.</p>', 'SendCommandRequest$DocumentName' => '<p>Required. The name of the SSM document to execute. This can be an SSM public document or a custom document.</p>', ], ], 'DocumentAlreadyExists' => [ 'base' => '<p>The specified SSM document already exists.</p>', 'refs' => [], ], 'DocumentContent' => [ 'base' => NULL, 'refs' => [ 'CreateDocumentRequest$Content' => '<p>A valid JSON string.</p>', 'GetDocumentResult$Content' => '<p>The contents of the SSM document.</p>', ], ], 'DocumentDescription' => [ 'base' => '<p> Describes an SSM document. </p>', 'refs' => [ 'CreateDocumentResult$DocumentDescription' => '<p>Information about the SSM document.</p>', 'DescribeDocumentResult$Document' => '<p>Information about the SSM document.</p>', ], ], 'DocumentFilter' => [ 'base' => '<p>Describes a filter.</p>', 'refs' => [ 'DocumentFilterList$member' => NULL, ], ], 'DocumentFilterKey' => [ 'base' => NULL, 'refs' => [ 'DocumentFilter$key' => '<p>The name of the filter.</p>', ], ], 'DocumentFilterList' => [ 'base' => NULL, 'refs' => [ 'ListDocumentsRequest$DocumentFilterList' => '<p>One or more filters. Use a filter to return a more specific list of results.</p>', ], ], 'DocumentFilterValue' => [ 'base' => NULL, 'refs' => [ 'DocumentFilter$value' => '<p>The value of the filter.</p>', ], ], 'DocumentHash' => [ 'base' => NULL, 'refs' => [ 'DocumentDescription$Hash' => '<p>The Sha256 or Sha1 hash created by the system when the document was created. </p> <note> <p>Sha1 hashes have been deprecated.</p> </note>', 'SendCommandRequest$DocumentHash' => '<p>The Sha256 or Sha1 hash created by the system when the document was created. </p> <note> <p>Sha1 hashes have been deprecated.</p> </note>', ], ], 'DocumentHashType' => [ 'base' => NULL, 'refs' => [ 'DocumentDescription$HashType' => '<p>Sha256 or Sha1.</p> <note> <p>Sha1 hashes have been deprecated.</p> </note>', 'SendCommandRequest$DocumentHashType' => '<p>Sha256 or Sha1.</p> <note> <p>Sha1 hashes have been deprecated.</p> </note>', ], ], 'DocumentIdentifier' => [ 'base' => '<p>Describes the name of an SSM document.</p>', 'refs' => [ 'DocumentIdentifierList$member' => NULL, ], ], 'DocumentIdentifierList' => [ 'base' => NULL, 'refs' => [ 'ListDocumentsResult$DocumentIdentifiers' => '<p>The names of the SSM documents.</p>', ], ], 'DocumentLimitExceeded' => [ 'base' => '<p>You can have at most 100 active SSM documents.</p>', 'refs' => [], ], 'DocumentName' => [ 'base' => NULL, 'refs' => [ 'Association$Name' => '<p>The name of the SSM document.</p>', 'AssociationDescription$Name' => '<p>The name of the SSM document.</p>', 'Command$DocumentName' => '<p>The name of the SSM document requested for execution.</p>', 'CommandInvocation$DocumentName' => '<p>The document name that was requested for execution.</p>', 'CreateAssociationBatchRequestEntry$Name' => '<p> The name of the configuration document. </p>', 'CreateAssociationRequest$Name' => '<p>The name of the SSM document.</p>', 'CreateDocumentRequest$Name' => '<p>A name for the SSM document.</p>', 'DeleteAssociationRequest$Name' => '<p>The name of the SSM document.</p>', 'DeleteDocumentRequest$Name' => '<p>The name of the SSM document.</p>', 'DescribeAssociationRequest$Name' => '<p>The name of the SSM document.</p>', 'DescribeDocumentPermissionRequest$Name' => '<p>The name of the document for which you are the owner.</p>', 'ModifyDocumentPermissionRequest$Name' => '<p>The name of the document that you want to share.</p>', 'UpdateAssociationStatusRequest$Name' => '<p>The name of the SSM document.</p>', ], ], 'DocumentOwner' => [ 'base' => NULL, 'refs' => [ 'DocumentDescription$Owner' => '<p>The AWS user account of the person who created the document.</p>', 'DocumentIdentifier$Owner' => '<p>The AWS user account of the person who created the document.</p>', ], ], 'DocumentParameter' => [ 'base' => '<p>Parameters specified in the SSM document that execute on the server when the command is run. </p>', 'refs' => [ 'DocumentParameterList$member' => NULL, ], ], 'DocumentParameterDefaultValue' => [ 'base' => NULL, 'refs' => [ 'DocumentParameter$DefaultValue' => '<p>If specified, the default values for the parameters. Parameters without a default value are required. Parameters with a default value are optional.</p>', ], ], 'DocumentParameterDescrption' => [ 'base' => NULL, 'refs' => [ 'DocumentParameter$Description' => '<p>A description of what the parameter does, how to use it, the default value, and whether or not the parameter is optional.</p>', ], ], 'DocumentParameterList' => [ 'base' => NULL, 'refs' => [ 'DocumentDescription$Parameters' => '<p>A description of the parameters for a document.</p>', ], ], 'DocumentParameterName' => [ 'base' => NULL, 'refs' => [ 'DocumentParameter$Name' => '<p>The name of the parameter.</p>', ], ], 'DocumentParameterType' => [ 'base' => NULL, 'refs' => [ 'DocumentParameter$Type' => '<p>The type of parameter. The type can be either “String” or “StringList”.</p>', ], ], 'DocumentPermissionLimit' => [ 'base' => '<p>The document cannot be shared with more AWS user accounts. You can share a document with a maximum of 20 accounts. You can publicly share up to five documents. If you need to increase this limit, contact AWS Support.</p>', 'refs' => [], ], 'DocumentPermissionType' => [ 'base' => NULL, 'refs' => [ 'DescribeDocumentPermissionRequest$PermissionType' => '<p>The permission type for the document. The permission type can be <i>Share</i>.</p>', 'ModifyDocumentPermissionRequest$PermissionType' => '<p>The permission type for the document. The permission type can be <i>Share</i>.</p>', ], ], 'DocumentSha1' => [ 'base' => NULL, 'refs' => [ 'DocumentDescription$Sha1' => '<p>The SHA1 hash of the document, which you can use for verification purposes.</p>', ], ], 'DocumentStatus' => [ 'base' => NULL, 'refs' => [ 'DocumentDescription$Status' => '<p>The status of the SSM document.</p>', ], ], 'DuplicateInstanceId' => [ 'base' => '<p>You cannot specify an instance ID in more than one association.</p>', 'refs' => [], ], 'FailedCreateAssociation' => [ 'base' => '<p>Describes a failed association.</p>', 'refs' => [ 'FailedCreateAssociationList$member' => NULL, ], ], 'FailedCreateAssociationList' => [ 'base' => NULL, 'refs' => [ 'CreateAssociationBatchResult$Failed' => '<p>Information about the associations that failed.</p>', ], ], 'Fault' => [ 'base' => NULL, 'refs' => [ 'FailedCreateAssociation$Fault' => '<p>The source of the failure.</p>', ], ], 'GetDocumentRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetDocumentResult' => [ 'base' => NULL, 'refs' => [], ], 'InstanceId' => [ 'base' => NULL, 'refs' => [ 'Association$InstanceId' => '<p>The ID of the instance.</p>', 'AssociationDescription$InstanceId' => '<p>The ID of the instance.</p>', 'CommandInvocation$InstanceId' => '<p>The instance ID in which this invocation was requested.</p>', 'CreateAssociationBatchRequestEntry$InstanceId' => '<p> The ID of the instance. </p>', 'CreateAssociationRequest$InstanceId' => '<p>The instance ID.</p>', 'DeleteAssociationRequest$InstanceId' => '<p>The ID of the instance.</p>', 'DescribeAssociationRequest$InstanceId' => '<p>The instance ID.</p>', 'InstanceIdList$member' => NULL, 'InstanceInformation$InstanceId' => '<p>The instance ID. </p>', 'ListCommandInvocationsRequest$InstanceId' => '<p>(Optional) The command execution details for a specific instance ID.</p>', 'ListCommandsRequest$InstanceId' => '<p>(Optional) Lists commands issued against this instance ID.</p>', 'UpdateAssociationStatusRequest$InstanceId' => '<p>The ID of the instance.</p>', ], ], 'InstanceIdList' => [ 'base' => NULL, 'refs' => [ 'CancelCommandRequest$InstanceIds' => '<p>(Optional) A list of instance IDs on which you want to cancel the command. If not provided, the command is canceled on every instance on which it was requested.</p>', 'Command$InstanceIds' => '<p>The instance IDs against which this command was requested.</p>', 'SendCommandRequest$InstanceIds' => '<p>Required. The instance IDs where the command should execute.</p>', ], ], 'InstanceInformation' => [ 'base' => '<p>Describes a filter for a specific list of instances. </p>', 'refs' => [ 'InstanceInformationList$member' => NULL, ], ], 'InstanceInformationFilter' => [ 'base' => '<p>Describes a filter for a specific list of instances. </p>', 'refs' => [ 'InstanceInformationFilterList$member' => NULL, ], ], 'InstanceInformationFilterKey' => [ 'base' => NULL, 'refs' => [ 'InstanceInformationFilter$key' => '<p>The name of the filter. </p>', ], ], 'InstanceInformationFilterList' => [ 'base' => NULL, 'refs' => [ 'DescribeInstanceInformationRequest$InstanceInformationFilterList' => '<p>One or more filters. Use a filter to return a more specific list of instances.</p>', ], ], 'InstanceInformationFilterValue' => [ 'base' => NULL, 'refs' => [ 'InstanceInformationFilterValueSet$member' => NULL, ], ], 'InstanceInformationFilterValueSet' => [ 'base' => NULL, 'refs' => [ 'InstanceInformationFilter$valueSet' => '<p>The filter values. </p>', ], ], 'InstanceInformationList' => [ 'base' => NULL, 'refs' => [ 'DescribeInstanceInformationResult$InstanceInformationList' => '<p>The instance information list.</p>', ], ], 'InternalServerError' => [ 'base' => '<p>An error occurred on the server side.</p>', 'refs' => [], ], 'InvalidCommandId' => [ 'base' => NULL, 'refs' => [], ], 'InvalidDocument' => [ 'base' => '<p>The specified document does not exist.</p>', 'refs' => [], ], 'InvalidDocumentContent' => [ 'base' => '<p>The content for the SSM document is not valid.</p>', 'refs' => [], ], 'InvalidDocumentOperation' => [ 'base' => '<p>You attempted to delete a document while it is still shared. You must stop sharing the document before you can delete it.</p>', 'refs' => [], ], 'InvalidFilterKey' => [ 'base' => '<p>The specified key is not valid.</p>', 'refs' => [], ], 'InvalidInstanceId' => [ 'base' => '<p>The instance is not in valid state. Valid states are: Running, Pending, Stopped, Stopping. Invalid states are: Shutting-down and Terminated. </p>', 'refs' => [], ], 'InvalidInstanceInformationFilterValue' => [ 'base' => '<p>The specified filter value is not valid.</p>', 'refs' => [], ], 'InvalidNextToken' => [ 'base' => '<p>The specified token is not valid.</p>', 'refs' => [], ], 'InvalidOutputFolder' => [ 'base' => '<p>The S3 bucket does not exist.</p>', 'refs' => [], ], 'InvalidParameters' => [ 'base' => '<p>You must specify values for all required parameters in the SSM document. You can only supply values to parameters defined in the SSM document.</p>', 'refs' => [], ], 'InvalidPermissionType' => [ 'base' => '<p>The permission type is not supported. <i>Share</i> is the only supported permission type.</p>', 'refs' => [], ], 'InvocationTraceOutput' => [ 'base' => NULL, 'refs' => [ 'CommandInvocation$TraceOutput' => '<p> Gets the trace output sent by the agent. </p>', ], ], 'ListAssociationsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListAssociationsResult' => [ 'base' => NULL, 'refs' => [], ], 'ListCommandInvocationsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListCommandInvocationsResult' => [ 'base' => NULL, 'refs' => [], ], 'ListCommandsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListCommandsResult' => [ 'base' => NULL, 'refs' => [], ], 'ListDocumentsMaxResults' => [ 'base' => NULL, 'refs' => [ 'ListDocumentsRequest$MaxResults' => '<p>The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.</p>', ], ], 'ListDocumentsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListDocumentsResult' => [ 'base' => NULL, 'refs' => [], ], 'MaxDocumentSizeExceeded' => [ 'base' => '<p>The size limit of an SSM document is 64 KB.</p>', 'refs' => [], ], 'MaxResults' => [ 'base' => NULL, 'refs' => [ 'ListAssociationsRequest$MaxResults' => '<p>The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.</p>', ], ], 'MaxResultsEC2Compatible' => [ 'base' => NULL, 'refs' => [ 'DescribeInstanceInformationRequest$MaxResults' => '<p>The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. </p>', ], ], 'ModifyDocumentPermissionRequest' => [ 'base' => NULL, 'refs' => [], ], 'ModifyDocumentPermissionResponse' => [ 'base' => NULL, 'refs' => [], ], 'NextToken' => [ 'base' => NULL, 'refs' => [ 'DescribeInstanceInformationRequest$NextToken' => '<p>The token for the next set of items to return. (You received this token from a previous call.)</p>', 'DescribeInstanceInformationResult$NextToken' => '<p>The token to use when requesting the next set of items. If there are no additional items to return, the string is empty. </p>', 'ListAssociationsRequest$NextToken' => '<p>The token for the next set of items to return. (You received this token from a previous call.)</p>', 'ListAssociationsResult$NextToken' => '<p>The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.</p>', 'ListCommandInvocationsRequest$NextToken' => '<p>(Optional) The token for the next set of items to return. (You received this token from a previous call.)</p>', 'ListCommandInvocationsResult$NextToken' => '<p>(Optional) The token for the next set of items to return. (You received this token from a previous call.)</p>', 'ListCommandsRequest$NextToken' => '<p>(Optional) The token for the next set of items to return. (You received this token from a previous call.)</p>', 'ListCommandsResult$NextToken' => '<p>(Optional) The token for the next set of items to return. (You received this token from a previous call.)</p>', 'ListDocumentsRequest$NextToken' => '<p>The token for the next set of items to return. (You received this token from a previous call.)</p>', 'ListDocumentsResult$NextToken' => '<p>The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.</p>', ], ], 'ParameterName' => [ 'base' => NULL, 'refs' => [ 'Parameters$key' => NULL, ], ], 'ParameterValue' => [ 'base' => NULL, 'refs' => [ 'ParameterValueList$member' => NULL, ], ], 'ParameterValueList' => [ 'base' => NULL, 'refs' => [ 'Parameters$value' => NULL, ], ], 'Parameters' => [ 'base' => NULL, 'refs' => [ 'AssociationDescription$Parameters' => '<p>A description of the parameters for a document. </p>', 'Command$Parameters' => '<p>The parameter values to be inserted in the SSM document when executing the command.</p>', 'CreateAssociationBatchRequestEntry$Parameters' => '<p>A description of the parameters for a document. </p>', 'CreateAssociationRequest$Parameters' => '<p>The parameters for the documents runtime configuration. </p>', 'SendCommandRequest$Parameters' => '<p>The required and optional parameters specified in the SSM document being executed.</p>', ], ], 'PingStatus' => [ 'base' => NULL, 'refs' => [ 'InstanceInformation$PingStatus' => '<p>Connection status of the SSM agent. </p>', ], ], 'PlatformType' => [ 'base' => NULL, 'refs' => [ 'InstanceInformation$PlatformType' => '<p>The operating system platform type. </p>', 'PlatformTypeList$member' => NULL, ], ], 'PlatformTypeList' => [ 'base' => NULL, 'refs' => [ 'DocumentDescription$PlatformTypes' => '<p>The list of OS platforms compatible with this SSM document. </p>', 'DocumentIdentifier$PlatformTypes' => '<p>The operating system platform. </p>', ], ], 'ResponseCode' => [ 'base' => NULL, 'refs' => [ 'CommandPlugin$ResponseCode' => '<p>A numeric response code generated after executing the plugin. </p>', ], ], 'S3BucketName' => [ 'base' => NULL, 'refs' => [ 'Command$OutputS3BucketName' => '<p>The S3 bucket where the responses to the command executions should be stored. This was requested when issuing the command.</p>', 'CommandPlugin$OutputS3BucketName' => '<p>The S3 bucket where the responses to the command executions should be stored. This was requested when issuing the command.</p>', 'SendCommandRequest$OutputS3BucketName' => '<p>The name of the S3 bucket where command execution responses should be stored.</p>', ], ], 'S3KeyPrefix' => [ 'base' => NULL, 'refs' => [ 'Command$OutputS3KeyPrefix' => '<p>The S3 directory path inside the bucket where the responses to the command executions should be stored. This was requested when issuing the command.</p>', 'CommandPlugin$OutputS3KeyPrefix' => '<p>The S3 directory path inside the bucket where the responses to the command executions should be stored. This was requested when issuing the command. </p>', 'SendCommandRequest$OutputS3KeyPrefix' => '<p>The directory structure within the S3 bucket where the responses should be stored.</p>', ], ], 'SendCommandRequest' => [ 'base' => NULL, 'refs' => [], ], 'SendCommandResult' => [ 'base' => NULL, 'refs' => [], ], 'StatusAdditionalInfo' => [ 'base' => NULL, 'refs' => [ 'AssociationStatus$AdditionalInfo' => '<p>A user-defined string.</p>', ], ], 'StatusMessage' => [ 'base' => NULL, 'refs' => [ 'AssociationStatus$Message' => '<p>The reason for the status.</p>', ], ], 'StatusUnchanged' => [ 'base' => '<p>The updated status is the same as the current status.</p>', 'refs' => [], ], 'String' => [ 'base' => NULL, 'refs' => [ 'DocumentAlreadyExists$Message' => NULL, 'DocumentLimitExceeded$Message' => NULL, 'DocumentPermissionLimit$Message' => NULL, 'InstanceInformation$PlatformName' => '<p>The name of the operating system platform running on your instance. </p>', 'InstanceInformation$PlatformVersion' => '<p>The version of the OS platform running on your instance. </p>', 'InternalServerError$Message' => NULL, 'InvalidDocument$Message' => '<p>The SSM document does not exist or the document is not available to the user. This exception can be issued by CreateAssociation, CreateAssociationBatch, DeleteAssociation, DeleteDocument, DescribeAssociation, DescribeDocument, GetDocument, SendCommand, or UpdateAssociationStatus. </p>', 'InvalidDocumentContent$Message' => '<p>A description of the validation error.</p>', 'InvalidDocumentOperation$Message' => NULL, 'InvalidInstanceId$Message' => NULL, 'InvalidInstanceInformationFilterValue$message' => NULL, 'InvalidParameters$Message' => NULL, 'InvalidPermissionType$Message' => NULL, 'MaxDocumentSizeExceeded$Message' => NULL, 'UnsupportedPlatformType$Message' => NULL, ], ], 'TimeoutSeconds' => [ 'base' => NULL, 'refs' => [ 'SendCommandRequest$TimeoutSeconds' => '<p>If this time is reached and the command has not already started executing, it will not execute.</p>', ], ], 'TooManyUpdates' => [ 'base' => '<p>There are concurrent updates for a resource that supports one update at a time.</p>', 'refs' => [], ], 'UnsupportedPlatformType' => [ 'base' => '<p>The document does not support the platform type of the given instance ID(s). For example, you sent an SSM document for a Windows instance to a Linux instance.</p>', 'refs' => [], ], 'UpdateAssociationStatusRequest' => [ 'base' => NULL, 'refs' => [], ], 'UpdateAssociationStatusResult' => [ 'base' => NULL, 'refs' => [], ], 'Version' => [ 'base' => NULL, 'refs' => [ 'InstanceInformation$AgentVersion' => '<p>The version of the SSM agent running on your instance. </p>', ], ], ],];
