<?php
// This file was auto-generated from sdk-root/src/data/waf/2015-08-24/docs-2.json
return [ 'version' => '2.0', 'service' => '<p>This is the <i>AWS WAF API Reference</i>. This guide is for developers who need detailed information about the AWS WAF API actions, data types, and errors. For detailed information about AWS WAF features and an overview of how to use the AWS WAF API, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'operations' => [ 'CreateByteMatchSet' => '<p>Creates a <code>ByteMatchSet</code>. You then use <a>UpdateByteMatchSet</a> to identify the part of a web request that you want AWS WAF to inspect, such as the values of the <code>User-Agent</code> header or the query string. For example, you can create a <code>ByteMatchSet</code> that matches any requests with <code>User-Agent</code> headers that contain the string <code>BadBot</code>. You can then configure AWS WAF to reject those requests.</p> <p>To create and configure a <code>ByteMatchSet</code>, perform the following steps:</p> <ol> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>CreateByteMatchSet</code> request.</li> <li>Submit a <code>CreateByteMatchSet</code> request.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <code>UpdateByteMatchSet</code> request.</li> <li>Submit an <a>UpdateByteMatchSet</a> request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value that you want AWS WAF to watch for.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'CreateIPSet' => '<p>Creates an <a>IPSet</a>, which you use to specify which web requests you want to allow or block based on the IP addresses that the requests originate from. For example, if you\'re receiving a lot of requests from one or more individual IP addresses or one or more ranges of IP addresses and you want to block the requests, you can create an <code>IPSet</code> that contains those IP addresses and then configure AWS WAF to block the requests. </p> <p>To create and configure an <code>IPSet</code>, perform the following steps:</p> <ol> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>CreateIPSet</code> request.</li> <li>Submit a <code>CreateIPSet</code> request.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateIPSet</a> request.</li> <li>Submit an <code>UpdateIPSet</code> request to specify the IP addresses that you want AWS WAF to watch for.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'CreateRule' => '<p>Creates a <code>Rule</code>, which contains the <code>IPSet</code> objects, <code>ByteMatchSet</code> objects, and other predicates that identify the requests that you want to block. If you add more than one predicate to a <code>Rule</code>, a request must match all of the specifications to be allowed or blocked. For example, suppose you add the following to a <code>Rule</code>:</p> <ul> <li>An <code>IPSet</code> that matches the IP address <code>192.0.2.44/32</code></li> <li>A <code>ByteMatchSet</code> that matches <code>BadBot</code> in the <code>User-Agent</code> header</li> </ul> <p>You then add the <code>Rule</code> to a <code>WebACL</code> and specify that you want to blocks requests that satisfy the <code>Rule</code>. For a request to be blocked, it must come from the IP address 192.0.2.44 <i>and</i> the <code>User-Agent</code> header in the request must contain the value <code>BadBot</code>.</p> <p>To create and configure a <code>Rule</code>, perform the following steps:</p> <ol> <li>Create and update the predicates that you want to include in the <code>Rule</code>. For more information, see <a>CreateByteMatchSet</a>, <a>CreateIPSet</a>, and <a>CreateSqlInjectionMatchSet</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>CreateRule</code> request.</li> <li>Submit a <code>CreateRule</code> request.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateRule</a> request.</li> <li>Submit an <code>UpdateRule</code> request to specify the predicates that you want to include in the <code>Rule</code>.</li> <li>Create and update a <code>WebACL</code> that contains the <code>Rule</code>. For more information, see <a>CreateWebACL</a>.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'CreateSizeConstraintSet' => '<p>Creates a <code>SizeConstraintSet</code>. You then use <a>UpdateSizeConstraintSet</a> to identify the part of a web request that you want AWS WAF to check for length, such as the length of the <code>User-Agent</code> header or the length of the query string. For example, you can create a <code>SizeConstraintSet</code> that matches any requests that have a query string that is longer than 100 bytes. You can then configure AWS WAF to reject those requests.</p> <p>To create and configure a <code>SizeConstraintSet</code>, perform the following steps:</p> <ol> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>CreateSizeConstraintSet</code> request.</li> <li>Submit a <code>CreateSizeConstraintSet</code> request.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <code>UpdateSizeConstraintSet</code> request.</li> <li>Submit an <a>UpdateSizeConstraintSet</a> request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value that you want AWS WAF to watch for.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'CreateSqlInjectionMatchSet' => '<p>Creates a <a>SqlInjectionMatchSet</a>, which you use to allow, block, or count requests that contain snippets of SQL code in a specified part of web requests. AWS WAF searches for character sequences that are likely to be malicious strings.</p> <p>To create and configure a <code>SqlInjectionMatchSet</code>, perform the following steps:</p> <ol> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>CreateSqlInjectionMatchSet</code> request.</li> <li>Submit a <code>CreateSqlInjectionMatchSet</code> request.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateSqlInjectionMatchSet</a> request.</li> <li>Submit an <a>UpdateSqlInjectionMatchSet</a> request to specify the parts of web requests in which you want to allow, block, or count malicious SQL code.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'CreateWebACL' => '<p>Creates a <code>WebACL</code>, which contains the <code>Rules</code> that identify the CloudFront web requests that you want to allow, block, or count. AWS WAF evaluates <code>Rules</code> in order based on the value of <code>Priority</code> for each <code>Rule</code>.</p> <p>You also specify a default action, either <code>ALLOW</code> or <code>BLOCK</code>. If a web request doesn\'t match any of the <code>Rules</code> in a <code>WebACL</code>, AWS WAF responds to the request with the default action. </p> <p>To create and configure a <code>WebACL</code>, perform the following steps:</p> <ol> <li>Create and update the <code>ByteMatchSet</code> objects and other predicates that you want to include in <code>Rules</code>. For more information, see <a>CreateByteMatchSet</a>, <a>UpdateByteMatchSet</a>, <a>CreateIPSet</a>, <a>UpdateIPSet</a>, <a>CreateSqlInjectionMatchSet</a>, and <a>UpdateSqlInjectionMatchSet</a>.</li> <li>Create and update the <code>Rules</code> that you want to include in the <code>WebACL</code>. For more information, see <a>CreateRule</a> and <a>UpdateRule</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>CreateWebACL</code> request.</li> <li>Submit a <code>CreateWebACL</code> request.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateWebACL</a> request.</li> <li>Submit an <a>UpdateWebACL</a> request to specify the <code>Rules</code> that you want to include in the <code>WebACL</code>, to specify the default action, and to associate the <code>WebACL</code> with a CloudFront distribution.</li> </ol> <p>For more information about how to use the AWS WAF API, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'CreateXssMatchSet' => '<p>Creates an <a>XssMatchSet</a>, which you use to allow, block, or count requests that contain cross-site scripting attacks in the specified part of web requests. AWS WAF searches for character sequences that are likely to be malicious strings.</p> <p>To create and configure an <code>XssMatchSet</code>, perform the following steps:</p> <ol> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>CreateXssMatchSet</code> request.</li> <li>Submit a <code>CreateXssMatchSet</code> request.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateXssMatchSet</a> request.</li> <li>Submit an <a>UpdateXssMatchSet</a> request to specify the parts of web requests in which you want to allow, block, or count cross-site scripting attacks.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'DeleteByteMatchSet' => '<p>Permanently deletes a <a>ByteMatchSet</a>. You can\'t delete a <code>ByteMatchSet</code> if it\'s still used in any <code>Rules</code> or if it still includes any <a>ByteMatchTuple</a> objects (any filters).</p> <p>If you just want to remove a <code>ByteMatchSet</code> from a <code>Rule</code>, use <a>UpdateRule</a>.</p> <p>To permanently delete a <code>ByteMatchSet</code>, perform the following steps:</p> <ol> <li>Update the <code>ByteMatchSet</code> to remove filters, if any. For more information, see <a>UpdateByteMatchSet</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>DeleteByteMatchSet</code> request.</li> <li>Submit a <code>DeleteByteMatchSet</code> request.</li> </ol>', 'DeleteIPSet' => '<p>Permanently deletes an <a>IPSet</a>. You can\'t delete an <code>IPSet</code> if it\'s still used in any <code>Rules</code> or if it still includes any IP addresses.</p> <p>If you just want to remove an <code>IPSet</code> from a <code>Rule</code>, use <a>UpdateRule</a>.</p> <p>To permanently delete an <code>IPSet</code> from AWS WAF, perform the following steps:</p> <ol> <li>Update the <code>IPSet</code> to remove IP address ranges, if any. For more information, see <a>UpdateIPSet</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>DeleteIPSet</code> request.</li> <li>Submit a <code>DeleteIPSet</code> request.</li> </ol>', 'DeleteRule' => '<p>Permanently deletes a <a>Rule</a>. You can\'t delete a <code>Rule</code> if it\'s still used in any <code>WebACL</code> objects or if it still includes any predicates, such as <code>ByteMatchSet</code> objects.</p> <p>If you just want to remove a <code>Rule</code> from a <code>WebACL</code>, use <a>UpdateWebACL</a>.</p> <p>To permanently delete a <code>Rule</code> from AWS WAF, perform the following steps:</p> <ol> <li>Update the <code>Rule</code> to remove predicates, if any. For more information, see <a>UpdateRule</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>DeleteRule</code> request.</li> <li>Submit a <code>DeleteRule</code> request.</li> </ol>', 'DeleteSizeConstraintSet' => '<p>Permanently deletes a <a>SizeConstraintSet</a>. You can\'t delete a <code>SizeConstraintSet</code> if it\'s still used in any <code>Rules</code> or if it still includes any <a>SizeConstraint</a> objects (any filters).</p> <p>If you just want to remove a <code>SizeConstraintSet</code> from a <code>Rule</code>, use <a>UpdateRule</a>.</p> <p>To permanently delete a <code>SizeConstraintSet</code>, perform the following steps:</p> <ol> <li>Update the <code>SizeConstraintSet</code> to remove filters, if any. For more information, see <a>UpdateSizeConstraintSet</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>DeleteSizeConstraintSet</code> request.</li> <li>Submit a <code>DeleteSizeConstraintSet</code> request.</li> </ol>', 'DeleteSqlInjectionMatchSet' => '<p>Permanently deletes a <a>SqlInjectionMatchSet</a>. You can\'t delete a <code>SqlInjectionMatchSet</code> if it\'s still used in any <code>Rules</code> or if it still contains any <a>SqlInjectionMatchTuple</a> objects.</p> <p>If you just want to remove a <code>SqlInjectionMatchSet</code> from a <code>Rule</code>, use <a>UpdateRule</a>.</p> <p>To permanently delete a <code>SqlInjectionMatchSet</code> from AWS WAF, perform the following steps:</p> <ol> <li>Update the <code>SqlInjectionMatchSet</code> to remove filters, if any. For more information, see <a>UpdateSqlInjectionMatchSet</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>DeleteSqlInjectionMatchSet</code> request.</li> <li>Submit a <code>DeleteSqlInjectionMatchSet</code> request.</li> </ol>', 'DeleteWebACL' => '<p>Permanently deletes a <a>WebACL</a>. You can\'t delete a <code>WebACL</code> if it still contains any <code>Rules</code>.</p> <p>To delete a <code>WebACL</code>, perform the following steps:</p> <ol> <li>Update the <code>WebACL</code> to remove <code>Rules</code>, if any. For more information, see <a>UpdateWebACL</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>DeleteWebACL</code> request.</li> <li>Submit a <code>DeleteWebACL</code> request.</li> </ol>', 'DeleteXssMatchSet' => '<p>Permanently deletes an <a>XssMatchSet</a>. You can\'t delete an <code>XssMatchSet</code> if it\'s still used in any <code>Rules</code> or if it still contains any <a>XssMatchTuple</a> objects.</p> <p>If you just want to remove an <code>XssMatchSet</code> from a <code>Rule</code>, use <a>UpdateRule</a>.</p> <p>To permanently delete an <code>XssMatchSet</code> from AWS WAF, perform the following steps:</p> <ol> <li>Update the <code>XssMatchSet</code> to remove filters, if any. For more information, see <a>UpdateXssMatchSet</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of a <code>DeleteXssMatchSet</code> request.</li> <li>Submit a <code>DeleteXssMatchSet</code> request.</li> </ol>', 'GetByteMatchSet' => '<p>Returns the <a>ByteMatchSet</a> specified by <code>ByteMatchSetId</code>.</p>', 'GetChangeToken' => '<p>When you want to create, update, or delete AWS WAF objects, get a change token and include the change token in the create, update, or delete request. Change tokens ensure that your application doesn\'t submit conflicting requests to AWS WAF.</p> <p>Each create, update, or delete request must use a unique change token. If your application submits a <code>GetChangeToken</code> request and then submits a second <code>GetChangeToken</code> request before submitting a create, update, or delete request, the second <code>GetChangeToken</code> request returns the same value as the first <code>GetChangeToken</code> request.</p> <p>When you use a change token in a create, update, or delete request, the status of the change token changes to <code>PENDING</code>, which indicates that AWS WAF is propagating the change to all AWS WAF servers. Use <code>GetChangeTokenStatus</code> to determine the status of your change token.</p>', 'GetChangeTokenStatus' => '<p>Returns the status of a <code>ChangeToken</code> that you got by calling <a>GetChangeToken</a>. <code>ChangeTokenStatus</code> is one of the following values:</p> <ul> <li><code>PROVISIONED</code>: You requested the change token by calling <code>GetChangeToken</code>, but you haven\'t used it yet in a call to create, update, or delete an AWS WAF object.</li> <li><code>PENDING</code>: AWS WAF is propagating the create, update, or delete request to all AWS WAF servers.</li> <li><code>IN_SYNC</code>: Propagation is complete.</li> </ul>', 'GetIPSet' => '<p>Returns the <a>IPSet</a> that is specified by <code>IPSetId</code>.</p>', 'GetRule' => '<p>Returns the <a>Rule</a> that is specified by the <code>RuleId</code> that you included in the <code>GetRule</code> request.</p>', 'GetSampledRequests' => '<p>Gets detailed information about a specified number of requests--a sample--that AWS WAF randomly selects from among the first 5,000 requests that your AWS resource received during a time range that you choose. You can specify a sample size of up to 100 requests, and you can specify any time range in the previous three hours.</p> <p><code>GetSampledRequests</code> returns a time range, which is usually the time range that you specified. However, if your resource (such as a CloudFront distribution) received 5,000 requests before the specified time range elapsed, <code>GetSampledRequests</code> returns an updated time range. This new time range indicates the actual period during which AWS WAF selected the requests in the sample.</p>', 'GetSizeConstraintSet' => '<p>Returns the <a>SizeConstraintSet</a> specified by <code>SizeConstraintSetId</code>.</p>', 'GetSqlInjectionMatchSet' => '<p>Returns the <a>SqlInjectionMatchSet</a> that is specified by <code>SqlInjectionMatchSetId</code>.</p>', 'GetWebACL' => '<p>Returns the <a>WebACL</a> that is specified by <code>WebACLId</code>.</p>', 'GetXssMatchSet' => '<p>Returns the <a>XssMatchSet</a> that is specified by <code>XssMatchSetId</code>.</p>', 'ListByteMatchSets' => '<p>Returns an array of <a>ByteMatchSetSummary</a> objects.</p>', 'ListIPSets' => '<p>Returns an array of <a>IPSetSummary</a> objects in the response.</p>', 'ListRules' => '<p>Returns an array of <a>RuleSummary</a> objects.</p>', 'ListSizeConstraintSets' => '<p>Returns an array of <a>SizeConstraintSetSummary</a> objects.</p>', 'ListSqlInjectionMatchSets' => '<p>Returns an array of <a>SqlInjectionMatchSet</a> objects.</p>', 'ListWebACLs' => '<p>Returns an array of <a>WebACLSummary</a> objects in the response.</p>', 'ListXssMatchSets' => '<p>Returns an array of <a>XssMatchSet</a> objects.</p>', 'UpdateByteMatchSet' => '<p>Inserts or deletes <a>ByteMatchTuple</a> objects (filters) in a <a>ByteMatchSet</a>. For each <code>ByteMatchTuple</code> object, you specify the following values: </p> <ul> <li>Whether to insert or delete the object from the array. If you want to change a <code>ByteMatchSetUpdate</code> object, you delete the existing object and add a new one.</li> <li>The part of a web request that you want AWS WAF to inspect, such as a query string or the value of the <code>User-Agent</code> header. </li> <li>The bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to look for. For more information, including how you specify the values for the AWS WAF API and the AWS CLI or SDKs, see <code>TargetString</code> in the <a>ByteMatchTuple</a> data type. </li> <li>Where to look, such as at the beginning or the end of a query string.</li> <li>Whether to perform any conversions on the request, such as converting it to lowercase, before inspecting it for the specified string.</li> </ul> <p>For example, you can add a <code>ByteMatchSetUpdate</code> object that matches web requests in which <code>User-Agent</code> headers contain the string <code>BadBot</code>. You can then configure AWS WAF to block those requests.</p> <p>To create and configure a <code>ByteMatchSet</code>, perform the following steps:</p> <ol> <li>Create a <code>ByteMatchSet.</code> For more information, see <a>CreateByteMatchSet</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <code>UpdateByteMatchSet</code> request.</li> <li>Submit an <code>UpdateByteMatchSet</code> request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value that you want AWS WAF to watch for.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'UpdateIPSet' => '<p>Inserts or deletes <a>IPSetDescriptor</a> objects in an <code>IPSet</code>. For each <code>IPSetDescriptor</code> object, you specify the following values: </p> <ul> <li>Whether to insert or delete the object from the array. If you want to change an <code>IPSetDescriptor</code> object, you delete the existing object and add a new one.</li> <li>The IP address version, <code>IPv4</code>. </li> <li>The IP address in CIDR notation, for example, <code>192.0.2.0/24</code> (for the range of IP addresses from <code>192.0.2.0</code> to <code>192.0.2.255</code>) or <code>192.0.2.44/32</code> (for the individual IP address <code>192.0.2.44</code>). </li> </ul> <p>AWS WAF supports /8, /16, /24, and /32 IP address ranges. For more information about CIDR notation, see the Wikipedia entry <a href="https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing">Classless Inter-Domain Routing</a>.</p> <p>You use an <code>IPSet</code> to specify which web requests you want to allow or block based on the IP addresses that the requests originated from. For example, if you\'re receiving a lot of requests from one or a small number of IP addresses and you want to block the requests, you can create an <code>IPSet</code> that specifies those IP addresses, and then configure AWS WAF to block the requests. </p> <p>To create and configure an <code>IPSet</code>, perform the following steps:</p> <ol> <li>Submit a <a>CreateIPSet</a> request.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateIPSet</a> request.</li> <li>Submit an <code>UpdateIPSet</code> request to specify the IP addresses that you want AWS WAF to watch for.</li> </ol> <p>When you update an <code>IPSet</code>, you specify the IP addresses that you want to add and/or the IP addresses that you want to delete. If you want to change an IP address, you delete the existing IP address and add the new one.</p> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'UpdateRule' => '<p>Inserts or deletes <a>Predicate</a> objects in a <code>Rule</code>. Each <code>Predicate</code> object identifies a predicate, such as a <a>ByteMatchSet</a> or an <a>IPSet</a>, that specifies the web requests that you want to allow, block, or count. If you add more than one predicate to a <code>Rule</code>, a request must match all of the specifications to be allowed, blocked, or counted. For example, suppose you add the following to a <code>Rule</code>: </p> <ul> <li>A <code>ByteMatchSet</code> that matches the value <code>BadBot</code> in the <code>User-Agent</code> header</li> <li>An <code>IPSet</code> that matches the IP address <code>192.0.2.44</code></li> </ul> <p>You then add the <code>Rule</code> to a <code>WebACL</code> and specify that you want to block requests that satisfy the <code>Rule</code>. For a request to be blocked, the <code>User-Agent</code> header in the request must contain the value <code>BadBot</code> <i>and</i> the request must originate from the IP address 192.0.2.44.</p> <p>To create and configure a <code>Rule</code>, perform the following steps:</p> <ol> <li>Create and update the predicates that you want to include in the <code>Rule</code>.</li> <li>Create the <code>Rule</code>. See <a>CreateRule</a>.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateRule</a> request.</li> <li>Submit an <code>UpdateRule</code> request to add predicates to the <code>Rule</code>.</li> <li>Create and update a <code>WebACL</code> that contains the <code>Rule</code>. See <a>CreateWebACL</a>.</li> </ol> <p>If you want to replace one <code>ByteMatchSet</code> or <code>IPSet</code> with another, you delete the existing one and add the new one.</p> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'UpdateSizeConstraintSet' => '<p>Inserts or deletes <a>SizeConstraint</a> objects (filters) in a <a>SizeConstraintSet</a>. For each <code>SizeConstraint</code> object, you specify the following values: </p> <ul> <li>Whether to insert or delete the object from the array. If you want to change a <code>SizeConstraintSetUpdate</code> object, you delete the existing object and add a new one.</li> <li>The part of a web request that you want AWS WAF to evaluate, such as the length of a query string or the length of the <code>User-Agent</code> header.</li> <li>Whether to perform any transformations on the request, such as converting it to lowercase, before checking its length. Note that transformations of the request body are not supported because the AWS resource forwards only the first <code>8192</code> bytes of your request to AWS WAF.</li> <li>A <code>ComparisonOperator</code> used for evaluating the selected part of the request against the specified <code>Size</code>, such as equals, greater than, less than, and so on.</li> <li>The length, in bytes, that you want AWS WAF to watch for in selected part of the request. The length is computed after applying the transformation.</li> </ul> <p>For example, you can add a <code>SizeConstraintSetUpdate</code> object that matches web requests in which the length of the <code>User-Agent</code> header is greater than 100 bytes. You can then configure AWS WAF to block those requests.</p> <p>To create and configure a <code>SizeConstraintSet</code>, perform the following steps:</p> <ol> <li>Create a <code>SizeConstraintSet.</code> For more information, see <a>CreateSizeConstraintSet</a>.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <code>UpdateSizeConstraintSet</code> request.</li> <li>Submit an <code>UpdateSizeConstraintSet</code> request to specify the part of the request that you want AWS WAF to inspect (for example, the header or the URI) and the value that you want AWS WAF to watch for.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'UpdateSqlInjectionMatchSet' => '<p>Inserts or deletes <a>SqlInjectionMatchTuple</a> objects (filters) in a <a>SqlInjectionMatchSet</a>. For each <code>SqlInjectionMatchTuple</code> object, you specify the following values:</p> <ul> <li><code>Action</code>: Whether to insert the object into or delete the object from the array. To change a <code>SqlInjectionMatchTuple</code>, you delete the existing object and add a new one.</li> <li><code>FieldToMatch</code>: The part of web requests that you want AWS WAF to inspect and, if you want AWS WAF to inspect a header, the name of the header.</li> <li><code>TextTransformation</code>: Which text transformation, if any, to perform on the web request before inspecting the request for snippets of malicious SQL code.</li> </ul> <p>You use <code>SqlInjectionMatchSet</code> objects to specify which CloudFront requests you want to allow, block, or count. For example, if you\'re receiving requests that contain snippets of SQL code in the query string and you want to block the requests, you can create a <code>SqlInjectionMatchSet</code> with the applicable settings, and then configure AWS WAF to block the requests. </p> <p>To create and configure a <code>SqlInjectionMatchSet</code>, perform the following steps:</p> <ol> <li>Submit a <a>CreateSqlInjectionMatchSet</a> request.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateIPSet</a> request.</li> <li>Submit an <code>UpdateSqlInjectionMatchSet</code> request to specify the parts of web requests that you want AWS WAF to inspect for snippets of SQL code.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'UpdateWebACL' => '<p>Inserts or deletes <a>ActivatedRule</a> objects in a <code>WebACL</code>. Each <code>Rule</code> identifies web requests that you want to allow, block, or count. When you update a <code>WebACL</code>, you specify the following values:</p> <ul> <li>A default action for the <code>WebACL</code>, either <code>ALLOW</code> or <code>BLOCK</code>. AWS WAF performs the default action if a request doesn\'t match the criteria in any of the <code>Rules</code> in a <code>WebACL</code>.</li> <li>The <code>Rules</code> that you want to add and/or delete. If you want to replace one <code>Rule</code> with another, you delete the existing <code>Rule</code> and add the new one.</li> <li>For each <code>Rule</code>, whether you want AWS WAF to allow requests, block requests, or count requests that match the conditions in the <code>Rule</code>.</li> <li>The order in which you want AWS WAF to evaluate the <code>Rules</code> in a <code>WebACL</code>. If you add more than one <code>Rule</code> to a <code>WebACL</code>, AWS WAF evaluates each request against the <code>Rules</code> in order based on the value of <code>Priority</code>. (The <code>Rule</code> that has the lowest value for <code>Priority</code> is evaluated first.) When a web request matches all of the predicates (such as <code>ByteMatchSets</code> and <code>IPSets</code>) in a <code>Rule</code>, AWS WAF immediately takes the corresponding action, allow or block, and doesn\'t evaluate the request against the remaining <code>Rules</code> in the <code>WebACL</code>, if any. </li> <li>The CloudFront distribution that you want to associate with the <code>WebACL</code>.</li> </ul> <p>To create and configure a <code>WebACL</code>, perform the following steps:</p> <ol> <li>Create and update the predicates that you want to include in <code>Rules</code>. For more information, see <a>CreateByteMatchSet</a>, <a>UpdateByteMatchSet</a>, <a>CreateIPSet</a>, <a>UpdateIPSet</a>, <a>CreateSqlInjectionMatchSet</a>, and <a>UpdateSqlInjectionMatchSet</a>.</li> <li>Create and update the <code>Rules</code> that you want to include in the <code>WebACL</code>. For more information, see <a>CreateRule</a> and <a>UpdateRule</a>.</li> <li>Create a <code>WebACL</code>. See <a>CreateWebACL</a>.</li> <li>Use <code>GetChangeToken</code> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateWebACL</a> request.</li> <li>Submit an <code>UpdateWebACL</code> request to specify the <code>Rules</code> that you want to include in the <code>WebACL</code>, to specify the default action, and to associate the <code>WebACL</code> with a CloudFront distribution. </li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', 'UpdateXssMatchSet' => '<p>Inserts or deletes <a>XssMatchTuple</a> objects (filters) in an <a>XssMatchSet</a>. For each <code>XssMatchTuple</code> object, you specify the following values:</p> <ul> <li><code>Action</code>: Whether to insert the object into or delete the object from the array. To change a <code>XssMatchTuple</code>, you delete the existing object and add a new one.</li> <li><code>FieldToMatch</code>: The part of web requests that you want AWS WAF to inspect and, if you want AWS WAF to inspect a header, the name of the header.</li> <li><code>TextTransformation</code>: Which text transformation, if any, to perform on the web request before inspecting the request for cross-site scripting attacks.</li> </ul> <p>You use <code>XssMatchSet</code> objects to specify which CloudFront requests you want to allow, block, or count. For example, if you\'re receiving requests that contain cross-site scripting attacks in the request body and you want to block the requests, you can create an <code>XssMatchSet</code> with the applicable settings, and then configure AWS WAF to block the requests. </p> <p>To create and configure an <code>XssMatchSet</code>, perform the following steps:</p> <ol> <li>Submit a <a>CreateXssMatchSet</a> request.</li> <li>Use <a>GetChangeToken</a> to get the change token that you provide in the <code>ChangeToken</code> parameter of an <a>UpdateIPSet</a> request.</li> <li>Submit an <code>UpdateXssMatchSet</code> request to specify the parts of web requests that you want AWS WAF to inspect for cross-site scripting attacks.</li> </ol> <p>For more information about how to use the AWS WAF API to allow or block HTTP requests, see the <a href="http://docs.aws.amazon.com/waf/latest/developerguide/">AWS WAF Developer Guide</a>.</p>', ], 'shapes' => [ 'Action' => [ 'base' => NULL, 'refs' => [ 'SampledHTTPRequest$Action' => '<p>The action for the <code>Rule</code> that the request matched: <code>ALLOW</code>, <code>BLOCK</code>, or <code>COUNT</code>.</p>', ], ], 'ActivatedRule' => [ 'base' => '<p>The <code>ActivatedRule</code> object in an <a>UpdateWebACL</a> request specifies a <code>Rule</code> that you want to insert or delete, the priority of the <code>Rule</code> in the <code>WebACL</code>, and the action that you want AWS WAF to take when a web request matches the <code>Rule</code> (<code>ALLOW</code>, <code>BLOCK</code>, or <code>COUNT</code>).</p> <p>To specify whether to insert or delete a <code>Rule</code>, use the <code>Action</code> parameter in the <a>WebACLUpdate</a> data type.</p>', 'refs' => [ 'ActivatedRules$member' => NULL, 'WebACLUpdate$ActivatedRule' => NULL, ], ], 'ActivatedRules' => [ 'base' => NULL, 'refs' => [ 'WebACL$Rules' => '<p>An array that contains the action for each <code>Rule</code> in a <code>WebACL</code>, the priority of the <code>Rule</code>, and the ID of the <code>Rule</code>.</p>', ], ], 'ByteMatchSet' => [ 'base' => '<p>In a <a>GetByteMatchSet</a> request, <code>ByteMatchSet</code> is a complex type that contains the <code>ByteMatchSetId</code> and <code>Name</code> of a <code>ByteMatchSet</code>, and the values that you specified when you updated the <code>ByteMatchSet</code>. </p> <p>A complex type that contains <code>ByteMatchTuple</code> objects, which specify the parts of web requests that you want AWS WAF to inspect and the values that you want AWS WAF to search for. If a <code>ByteMatchSet</code> contains more than one <code>ByteMatchTuple</code> object, a request needs to match the settings in only one <code>ByteMatchTuple</code> to be considered a match.</p>', 'refs' => [ 'CreateByteMatchSetResponse$ByteMatchSet' => '<p>A <a>ByteMatchSet</a> that contains no <code>ByteMatchTuple</code> objects.</p>', 'GetByteMatchSetResponse$ByteMatchSet' => '<p>Information about the <a>ByteMatchSet</a> that you specified in the <code>GetByteMatchSet</code> request. For more information, see the following topics:</p> <ul> <li><a>ByteMatchSet</a>: Contains <code>ByteMatchSetId</code>, <code>ByteMatchTuples</code>, and <code>Name</code></li> <li><code>ByteMatchTuples</code>: Contains an array of <a>ByteMatchTuple</a> objects. Each <code>ByteMatchTuple</code> object contains <a>FieldToMatch</a>, <code>PositionalConstraint</code>, <code>TargetString</code>, and <code>TextTransformation</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'ByteMatchSetSummaries' => [ 'base' => NULL, 'refs' => [ 'ListByteMatchSetsResponse$ByteMatchSets' => '<p>An array of <a>ByteMatchSetSummary</a> objects.</p>', ], ], 'ByteMatchSetSummary' => [ 'base' => '<p>Returned by <a>ListByteMatchSets</a>. Each <code>ByteMatchSetSummary</code> object includes the <code>Name</code> and <code>ByteMatchSetId</code> for one <a>ByteMatchSet</a>.</p>', 'refs' => [ 'ByteMatchSetSummaries$member' => NULL, ], ], 'ByteMatchSetUpdate' => [ 'base' => '<p>In an <a>UpdateByteMatchSet</a> request, <code>ByteMatchSetUpdate</code> specifies whether to insert or delete a <a>ByteMatchTuple</a> and includes the settings for the <code>ByteMatchTuple</code>.</p>', 'refs' => [ 'ByteMatchSetUpdates$member' => NULL, ], ], 'ByteMatchSetUpdates' => [ 'base' => NULL, 'refs' => [ 'UpdateByteMatchSetRequest$Updates' => '<p>An array of <code>ByteMatchSetUpdate</code> objects that you want to insert into or delete from a <a>ByteMatchSet</a>. For more information, see the applicable data types:</p> <ul> <li><a>ByteMatchSetUpdate</a>: Contains <code>Action</code> and <code>ByteMatchTuple</code></li> <li><a>ByteMatchTuple</a>: Contains <code>FieldToMatch</code>, <code>PositionalConstraint</code>, <code>TargetString</code>, and <code>TextTransformation</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'ByteMatchTargetString' => [ 'base' => NULL, 'refs' => [ 'ByteMatchTuple$TargetString' => '<p>The value that you want AWS WAF to search for. AWS WAF searches for the specified string in the part of web requests that you specified in <code>FieldToMatch</code>. The maximum length of the value is 50 bytes.</p> <p>Valid values depend on the values that you specified for <code>FieldToMatch</code>:</p> <ul> <li><code>HEADER</code>: The value that you want AWS WAF to search for in the request header that you specified in <a>FieldToMatch</a>, for example, the value of the <code>User-Agent</code> or <code>Referer</code> header.</li> <li><code>METHOD</code>: The HTTP method, which indicates the type of operation specified in the request. CloudFront supports the following methods: <code>DELETE</code>, <code>GET</code>, <code>HEAD</code>, <code>OPTIONS</code>, <code>PATCH</code>, <code>POST</code>, and <code>PUT</code>.</li> <li><code>QUERY_STRING</code>: The value that you want AWS WAF to search for in the query string, which is the part of a URL that appears after a <code>?</code> character.</li> <li><code>URI</code>: The value that you want AWS WAF to search for in the part of a URL that identifies a resource, for example, <code>/images/daily-ad.jpg</code>.</li> <li><code>BODY</code>: The part of a request that contains any additional data that you want to send to your web server as the HTTP request body, such as data from a form. The request body immediately follows the request headers. Note that only the first <code>8192</code> bytes of the request body are forwarded to AWS WAF for inspection. To allow or block requests based on the length of the body, you can create a size constraint set. For more information, see <a>CreateSizeConstraintSet</a>. </li> </ul> <p>If <code>TargetString</code> includes alphabetic characters A-Z and a-z, note that the value is case sensitive.</p> <p><b>If you\'re using the AWS WAF API</b></p> <p>Specify a base64-encoded version of the value. The maximum length of the value before you base64-encode it is 50 bytes. </p> <p>For example, suppose the value of <code>Type</code> is <code>HEADER</code> and the value of <code>Data</code> is <code>User-Agent</code>. If you want to search the <code>User-Agent</code> header for the value <code>BadBot</code>, you base64-encode <code>BadBot</code> using MIME base64 encoding and include the resulting value, <code>QmFkQm90</code>, in the value of <code>TargetString</code>.</p> <p><b>If you\'re using the AWS CLI or one of the AWS SDKs</b></p> <p>The value that you want AWS WAF to search for. The SDK automatically base64 encodes the value.</p>', ], ], 'ByteMatchTuple' => [ 'base' => '<p>The bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings.</p>', 'refs' => [ 'ByteMatchSetUpdate$ByteMatchTuple' => '<p>Information about the part of a web request that you want AWS WAF to inspect and the value that you want AWS WAF to search for. If you specify <code>DELETE</code> for the value of <code>Action</code>, the <code>ByteMatchTuple</code> values must exactly match the values in the <code>ByteMatchTuple</code> that you want to delete from the <code>ByteMatchSet</code>.</p>', 'ByteMatchTuples$member' => NULL, ], ], 'ByteMatchTuples' => [ 'base' => NULL, 'refs' => [ 'ByteMatchSet$ByteMatchTuples' => '<p>Specifies the bytes (typically a string that corresponds with ASCII characters) that you want AWS WAF to search for in web requests, the location in requests that you want AWS WAF to search, and other settings.</p>', ], ], 'ChangeAction' => [ 'base' => NULL, 'refs' => [ 'ByteMatchSetUpdate$Action' => '<p>Specifies whether to insert or delete a <a>ByteMatchTuple</a>.</p>', 'IPSetUpdate$Action' => '<p>Specifies whether to insert or delete an IP address with <a>UpdateIPSet</a>.</p>', 'RuleUpdate$Action' => '<p>Specify <code>INSERT</code> to add a <code>Predicate</code> to a <code>Rule</code>. Use <code>DELETE</code> to remove a <code>Predicate</code> from a <code>Rule</code>.</p>', 'SizeConstraintSetUpdate$Action' => '<p>Specify <code>INSERT</code> to add a <a>SizeConstraintSetUpdate</a> to a <a>SizeConstraintSet</a>. Use <code>DELETE</code> to remove a <code>SizeConstraintSetUpdate</code> from a <code>SizeConstraintSet</code>.</p>', 'SqlInjectionMatchSetUpdate$Action' => '<p>Specify <code>INSERT</code> to add a <a>SqlInjectionMatchSetUpdate</a> to a <a>SqlInjectionMatchSet</a>. Use <code>DELETE</code> to remove a <code>SqlInjectionMatchSetUpdate</code> from a <code>SqlInjectionMatchSet</code>.</p>', 'WebACLUpdate$Action' => '<p>Specifies whether to insert a <code>Rule</code> into or delete a <code>Rule</code> from a <code>WebACL</code>.</p>', 'XssMatchSetUpdate$Action' => '<p>Specify <code>INSERT</code> to add a <a>XssMatchSetUpdate</a> to an <a>XssMatchSet</a>. Use <code>DELETE</code> to remove a <code>XssMatchSetUpdate</code> from an <code>XssMatchSet</code>.</p>', ], ], 'ChangeToken' => [ 'base' => NULL, 'refs' => [ 'CreateByteMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'CreateByteMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>CreateByteMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'CreateIPSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'CreateIPSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>CreateIPSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'CreateRuleRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'CreateRuleResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>CreateRule</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'CreateSizeConstraintSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'CreateSizeConstraintSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>CreateSizeConstraintSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'CreateSqlInjectionMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'CreateSqlInjectionMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>CreateSqlInjectionMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'CreateWebACLRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'CreateWebACLResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>CreateWebACL</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'CreateXssMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'CreateXssMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>CreateXssMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'DeleteByteMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'DeleteByteMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>DeleteByteMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'DeleteIPSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'DeleteIPSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>DeleteIPSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'DeleteRuleRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'DeleteRuleResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>DeleteRule</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'DeleteSizeConstraintSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'DeleteSizeConstraintSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>DeleteSizeConstraintSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'DeleteSqlInjectionMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'DeleteSqlInjectionMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>DeleteSqlInjectionMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'DeleteWebACLRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'DeleteWebACLResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>DeleteWebACL</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'DeleteXssMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'DeleteXssMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>DeleteXssMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'GetChangeTokenResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used in the request. Use this value in a <code>GetChangeTokenStatus</code> request to get the current status of the request. </p>', 'GetChangeTokenStatusRequest$ChangeToken' => '<p>The change token for which you want to get the status. This change token was previously returned in the <code>GetChangeToken</code> response.</p>', 'UpdateByteMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'UpdateByteMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>UpdateByteMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'UpdateIPSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'UpdateIPSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>UpdateIPSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'UpdateRuleRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'UpdateRuleResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>UpdateRule</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'UpdateSizeConstraintSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'UpdateSizeConstraintSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>UpdateSizeConstraintSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'UpdateSqlInjectionMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'UpdateSqlInjectionMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>UpdateSqlInjectionMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'UpdateWebACLRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'UpdateWebACLResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>UpdateWebACL</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', 'UpdateXssMatchSetRequest$ChangeToken' => '<p>The value returned by the most recent call to <a>GetChangeToken</a>.</p>', 'UpdateXssMatchSetResponse$ChangeToken' => '<p>The <code>ChangeToken</code> that you used to submit the <code>UpdateXssMatchSet</code> request. You can also use this value to query the status of the request. For more information, see <a>GetChangeTokenStatus</a>.</p>', ], ], 'ChangeTokenStatus' => [ 'base' => NULL, 'refs' => [ 'GetChangeTokenStatusResponse$ChangeTokenStatus' => '<p>The status of the change token.</p>', ], ], 'ComparisonOperator' => [ 'base' => NULL, 'refs' => [ 'SizeConstraint$ComparisonOperator' => '<p>The type of comparison you want AWS WAF to perform. AWS WAF uses this in combination with the provided <code>Size</code> and <code>FieldToMatch</code> to build an expression in the form of "<code>Size</code> <code>ComparisonOperator</code> size in bytes of <code>FieldToMatch</code>". If that expression is true, the <code>SizeConstraint</code> is considered to match.</p> <p><b>EQ</b>: Used to test if the <code>Size</code> is equal to the size of the <code>FieldToMatch</code></p> <p><b>NE</b>: Used to test if the <code>Size</code> is not equal to the size of the <code>FieldToMatch</code></p> <p><b>LE</b>: Used to test if the <code>Size</code> is less than or equal to the size of the <code>FieldToMatch</code></p> <p><b>LT</b>: Used to test if the <code>Size</code> is strictly less than the size of the <code>FieldToMatch</code></p> <p><b>GE</b>: Used to test if the <code>Size</code> is greater than or equal to the size of the <code>FieldToMatch</code></p> <p><b>GT</b>: Used to test if the <code>Size</code> is strictly greater than the size of the <code>FieldToMatch</code></p>', ], ], 'Country' => [ 'base' => NULL, 'refs' => [ 'HTTPRequest$Country' => '<p>The two-letter country code for the country that the request originated from. For a current list of country codes, see the Wikipedia entry <a href="https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2">ISO 3166-1 alpha-2</a>.</p>', ], ], 'CreateByteMatchSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateByteMatchSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'CreateIPSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateIPSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'CreateRuleRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateRuleResponse' => [ 'base' => NULL, 'refs' => [], ], 'CreateSizeConstraintSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateSizeConstraintSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'CreateSqlInjectionMatchSetRequest' => [ 'base' => '<p>A request to create a <a>SqlInjectionMatchSet</a>.</p>', 'refs' => [], ], 'CreateSqlInjectionMatchSetResponse' => [ 'base' => '<p>The response to a <code>CreateSqlInjectionMatchSet</code> request.</p>', 'refs' => [], ], 'CreateWebACLRequest' => [ 'base' => NULL, 'refs' => [], ], 'CreateWebACLResponse' => [ 'base' => NULL, 'refs' => [], ], 'CreateXssMatchSetRequest' => [ 'base' => '<p>A request to create an <a>XssMatchSet</a>.</p>', 'refs' => [], ], 'CreateXssMatchSetResponse' => [ 'base' => '<p>The response to a <code>CreateXssMatchSet</code> request.</p>', 'refs' => [], ], 'DeleteByteMatchSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteByteMatchSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'DeleteIPSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteIPSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'DeleteRuleRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteRuleResponse' => [ 'base' => NULL, 'refs' => [], ], 'DeleteSizeConstraintSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteSizeConstraintSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'DeleteSqlInjectionMatchSetRequest' => [ 'base' => '<p>A request to delete a <a>SqlInjectionMatchSet</a> from AWS WAF.</p>', 'refs' => [], ], 'DeleteSqlInjectionMatchSetResponse' => [ 'base' => '<p>The response to a request to delete a <a>SqlInjectionMatchSet</a> from AWS WAF.</p>', 'refs' => [], ], 'DeleteWebACLRequest' => [ 'base' => NULL, 'refs' => [], ], 'DeleteWebACLResponse' => [ 'base' => NULL, 'refs' => [], ], 'DeleteXssMatchSetRequest' => [ 'base' => '<p>A request to delete an <a>XssMatchSet</a> from AWS WAF.</p>', 'refs' => [], ], 'DeleteXssMatchSetResponse' => [ 'base' => '<p>The response to a request to delete an <a>XssMatchSet</a> from AWS WAF.</p>', 'refs' => [], ], 'FieldToMatch' => [ 'base' => '<p>Specifies where in a web request to look for <code>TargetString</code>.</p>', 'refs' => [ 'ByteMatchTuple$FieldToMatch' => '<p>The part of a web request that you want AWS WAF to search, such as a specified header or a query string. For more information, see <a>FieldToMatch</a>.</p>', 'SizeConstraint$FieldToMatch' => NULL, 'SqlInjectionMatchTuple$FieldToMatch' => NULL, 'XssMatchTuple$FieldToMatch' => NULL, ], ], 'GetByteMatchSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetByteMatchSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetChangeTokenRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetChangeTokenResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetChangeTokenStatusRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetChangeTokenStatusResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetIPSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetIPSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetRuleRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetRuleResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetSampledRequestsRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetSampledRequestsResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetSizeConstraintSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetSizeConstraintSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetSqlInjectionMatchSetRequest' => [ 'base' => '<p>A request to get a <a>SqlInjectionMatchSet</a>.</p>', 'refs' => [], ], 'GetSqlInjectionMatchSetResponse' => [ 'base' => '<p>The response to a <a>GetSqlInjectionMatchSet</a> request.</p>', 'refs' => [], ], 'GetWebACLRequest' => [ 'base' => NULL, 'refs' => [], ], 'GetWebACLResponse' => [ 'base' => NULL, 'refs' => [], ], 'GetXssMatchSetRequest' => [ 'base' => '<p>A request to get an <a>XssMatchSet</a>.</p>', 'refs' => [], ], 'GetXssMatchSetResponse' => [ 'base' => '<p>The response to a <a>GetXssMatchSet</a> request.</p>', 'refs' => [], ], 'HTTPHeader' => [ 'base' => '<p>The response from a <a>GetSampledRequests</a> request includes an <code>HTTPHeader</code> complex type that appears as <code>Headers</code> in the response syntax. <code>HTTPHeader</code> contains the names and values of all of the headers that appear in one of the web requests that were returned by <code>GetSampledRequests</code>. </p>', 'refs' => [ 'HTTPHeaders$member' => NULL, ], ], 'HTTPHeaders' => [ 'base' => NULL, 'refs' => [ 'HTTPRequest$Headers' => '<p>A complex type that contains two values for each header in the sampled web request: the name of the header and the value of the header.</p>', ], ], 'HTTPMethod' => [ 'base' => NULL, 'refs' => [ 'HTTPRequest$Method' => '<p>The HTTP method specified in the sampled web request. CloudFront supports the following methods: <code>DELETE</code>, <code>GET</code>, <code>HEAD</code>, <code>OPTIONS</code>, <code>PATCH</code>, <code>POST</code>, and <code>PUT</code>. </p>', ], ], 'HTTPRequest' => [ 'base' => '<p>The response from a <a>GetSampledRequests</a> request includes an <code>HTTPRequest</code> complex type that appears as <code>Request</code> in the response syntax. <code>HTTPRequest</code> contains information about one of the web requests that were returned by <code>GetSampledRequests</code>. </p>', 'refs' => [ 'SampledHTTPRequest$Request' => '<p>A complex type that contains detailed information about the request.</p>', ], ], 'HTTPVersion' => [ 'base' => NULL, 'refs' => [ 'HTTPRequest$HTTPVersion' => '<p>The HTTP version specified in the sampled web request, for example, <code>HTTP/1.1</code>.</p>', ], ], 'HeaderName' => [ 'base' => NULL, 'refs' => [ 'HTTPHeader$Name' => '<p>The name of one of the headers in the sampled web request.</p>', ], ], 'HeaderValue' => [ 'base' => NULL, 'refs' => [ 'HTTPHeader$Value' => '<p>The value of one of the headers in the sampled web request.</p>', ], ], 'IPSet' => [ 'base' => '<p>Contains one or more IP addresses or blocks of IP addresses specified in Classless Inter-Domain Routing (CIDR) notation. To specify an individual IP address, you specify the four-part IP address followed by a <code>/32</code>, for example, 192.0.2.0/31. To block a range of IP addresses, you can specify a <code>/24</code>, a <code>/16</code>, or a <code>/8</code> CIDR. For more information about CIDR notation, perform an Internet search on <code>cidr notation</code>.</p>', 'refs' => [ 'CreateIPSetResponse$IPSet' => '<p>The <a>IPSet</a> returned in the <code>CreateIPSet</code> response.</p>', 'GetIPSetResponse$IPSet' => '<p>Information about the <a>IPSet</a> that you specified in the <code>GetIPSet</code> request. For more information, see the following topics:</p> <ul> <li><a>IPSet</a>: Contains <code>IPSetDescriptors</code>, <code>IPSetId</code>, and <code>Name</code></li> <li><code>IPSetDescriptors</code>: Contains an array of <a>IPSetDescriptor</a> objects. Each <code>IPSetDescriptor</code> object contains <code>Type</code> and <code>Value</code></li> </ul>', ], ], 'IPSetDescriptor' => [ 'base' => '<p>Specifies the IP address type (<code>IPV4</code>) and the IP address range (in CIDR format) that web requests originate from.</p>', 'refs' => [ 'IPSetDescriptors$member' => NULL, 'IPSetUpdate$IPSetDescriptor' => '<p>The IP address type (<code>IPV4</code>) and the IP address range (in CIDR notation) that web requests originate from.</p>', ], ], 'IPSetDescriptorType' => [ 'base' => NULL, 'refs' => [ 'IPSetDescriptor$Type' => '<p>Specify <code>IPV4</code>.</p>', ], ], 'IPSetDescriptorValue' => [ 'base' => NULL, 'refs' => [ 'IPSetDescriptor$Value' => '<p>Specify an IPv4 address by using CIDR notation. For example:</p> <ul> <li>To configure AWS WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify <code>192.0.2.44/32</code>.</li> <li>To configure AWS WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify <code>192.0.2.0/24</code>.</li> </ul> <p>AWS WAF supports only /8, /16, /24, and /32 IP addresses.</p> <p>For more information about CIDR notation, see the Wikipedia entry <a href="https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing">Classless Inter-Domain Routing</a>.</p>', ], ], 'IPSetDescriptors' => [ 'base' => NULL, 'refs' => [ 'IPSet$IPSetDescriptors' => '<p>The IP address type (<code>IPV4</code>) and the IP address range (in CIDR notation) that web requests originate from. If the <code>WebACL</code> is associated with a CloudFront distribution, this is the value of one of the following fields in CloudFront access logs:</p> <ul> <li><code>c-ip</code>, if the viewer did not use an HTTP proxy or a load balancer to send the request</li> <li><code>x-forwarded-for</code>, if the viewer did use an HTTP proxy or a load balancer to send the request</li> </ul>', ], ], 'IPSetSummaries' => [ 'base' => NULL, 'refs' => [ 'ListIPSetsResponse$IPSets' => '<p>An array of <a>IPSetSummary</a> objects.</p>', ], ], 'IPSetSummary' => [ 'base' => '<p>Contains the identifier and the name of the <code>IPSet</code>.</p>', 'refs' => [ 'IPSetSummaries$member' => NULL, ], ], 'IPSetUpdate' => [ 'base' => '<p>Specifies the type of update to perform to an <a>IPSet</a> with <a>UpdateIPSet</a>.</p>', 'refs' => [ 'IPSetUpdates$member' => NULL, ], ], 'IPSetUpdates' => [ 'base' => NULL, 'refs' => [ 'UpdateIPSetRequest$Updates' => '<p>An array of <code>IPSetUpdate</code> objects that you want to insert into or delete from an <a>IPSet</a>. For more information, see the applicable data types:</p> <ul> <li><a>IPSetUpdate</a>: Contains <code>Action</code> and <code>IPSetDescriptor</code></li> <li><a>IPSetDescriptor</a>: Contains <code>Type</code> and <code>Value</code></li> </ul>', ], ], 'IPString' => [ 'base' => NULL, 'refs' => [ 'HTTPRequest$ClientIP' => '<p>The IP address that the request originated from. If the <code>WebACL</code> is associated with a CloudFront distribution, this is the value of one of the following fields in CloudFront access logs:</p> <ul> <li><code>c-ip</code>, if the viewer did not use an HTTP proxy or a load balancer to send the request</li> <li><code>x-forwarded-for</code>, if the viewer did use an HTTP proxy or a load balancer to send the request</li> </ul>', ], ], 'ListByteMatchSetsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListByteMatchSetsResponse' => [ 'base' => NULL, 'refs' => [], ], 'ListIPSetsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListIPSetsResponse' => [ 'base' => NULL, 'refs' => [], ], 'ListMaxItems' => [ 'base' => NULL, 'refs' => [ 'GetSampledRequestsRequest$MaxItems' => '<p>The number of requests that you want AWS WAF to return from among the first 5,000 requests that your AWS resource received during the time range. If your resource received fewer requests than the value of <code>MaxItems</code>, <code>GetSampledRequests</code> returns information about all of them. </p>', ], ], 'ListRulesRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListRulesResponse' => [ 'base' => NULL, 'refs' => [], ], 'ListSizeConstraintSetsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListSizeConstraintSetsResponse' => [ 'base' => NULL, 'refs' => [], ], 'ListSqlInjectionMatchSetsRequest' => [ 'base' => '<p>A request to list the <a>SqlInjectionMatchSet</a> objects created by the current AWS account.</p>', 'refs' => [], ], 'ListSqlInjectionMatchSetsResponse' => [ 'base' => '<p>The response to a <a>ListSqlInjectionMatchSets</a> request.</p>', 'refs' => [], ], 'ListWebACLsRequest' => [ 'base' => NULL, 'refs' => [], ], 'ListWebACLsResponse' => [ 'base' => NULL, 'refs' => [], ], 'ListXssMatchSetsRequest' => [ 'base' => '<p>A request to list the <a>XssMatchSet</a> objects created by the current AWS account.</p>', 'refs' => [], ], 'ListXssMatchSetsResponse' => [ 'base' => '<p>The response to a <a>ListXssMatchSets</a> request.</p>', 'refs' => [], ], 'MatchFieldData' => [ 'base' => NULL, 'refs' => [ 'FieldToMatch$Data' => '<p>When the value of <code>Type</code> is <code>HEADER</code>, enter the name of the header that you want AWS WAF to search, for example, <code>User-Agent</code> or <code>Referer</code>. If the value of <code>Type</code> is any other value, omit <code>Data</code>.</p> <p>The name of the header is not case sensitive.</p>', ], ], 'MatchFieldType' => [ 'base' => NULL, 'refs' => [ 'FieldToMatch$Type' => '<p>The part of the web request that you want AWS WAF to search for a specified string. Parts of a request that you can search include the following:</p> <ul> <li><code>HEADER</code>: A specified request header, for example, the value of the <code>User-Agent</code> or <code>Referer</code> header. If you choose <code>HEADER</code> for the type, specify the name of the header in <code>Data</code>.</li> <li><code>METHOD</code>: The HTTP method, which indicated the type of operation that the request is asking the origin to perform. Amazon CloudFront supports the following methods: <code>DELETE</code>, <code>GET</code>, <code>HEAD</code>, <code>OPTIONS</code>, <code>PATCH</code>, <code>POST</code>, and <code>PUT</code>.</li> <li><code>QUERY_STRING</code>: A query string, which is the part of a URL that appears after a <code>?</code> character, if any.</li> <li><code>URI</code>: The part of a web request that identifies a resource, for example, <code>/images/daily-ad.jpg</code>.</li> <li><code>BODY</code>: The part of a request that contains any additional data that you want to send to your web server as the HTTP request body, such as data from a form. The request body immediately follows the request headers. Note that only the first <code>8192</code> bytes of the request body are forwarded to AWS WAF for inspection. To allow or block requests based on the length of the body, you can create a size constraint set. For more information, see <a>CreateSizeConstraintSet</a>. </li> </ul>', ], ], 'MetricName' => [ 'base' => NULL, 'refs' => [ 'CreateRuleRequest$MetricName' => '<p>A friendly name or description for the metrics for this <code>Rule</code>. The name can contain only alphanumeric characters (A-Z, a-z, 0-9); the name can\'t contain whitespace. You can\'t change the name of the metric after you create the <code>Rule</code>.</p>', 'CreateWebACLRequest$MetricName' => '<p>A friendly name or description for the metrics for this <code>WebACL</code>. The name can contain only alphanumeric characters (A-Z, a-z, 0-9); the name can\'t contain whitespace. You can\'t change <code>MetricName</code> after you create the <code>WebACL</code>.</p>', 'Rule$MetricName' => NULL, 'WebACL$MetricName' => NULL, ], ], 'Negated' => [ 'base' => NULL, 'refs' => [ 'Predicate$Negated' => '<p>Set <code>Negated</code> to <code>False</code> if you want AWS WAF to allow, block, or count requests based on the settings in the specified <a>ByteMatchSet</a>, <a>IPSet</a>, <a>SqlInjectionMatchSet</a>, <a>XssMatchSet</a>, or <a>SizeConstraintSet</a>. For example, if an <code>IPSet</code> includes the IP address <code>192.0.2.44</code>, AWS WAF will allow or block requests based on that IP address.</p> <p>Set <code>Negated</code> to <code>True</code> if you want AWS WAF to allow or block a request based on the negation of the settings in the <a>ByteMatchSet</a>, <a>IPSet</a>, <a>SqlInjectionMatchSet</a>, <a>XssMatchSet</a>, or <a>SizeConstraintSet</a>. For example, if an <code>IPSet</code> includes the IP address <code>192.0.2.44</code>, AWS WAF will allow, block, or count requests based on all IP addresses <i>except</i> <code>192.0.2.44</code>.</p>', ], ], 'NextMarker' => [ 'base' => NULL, 'refs' => [ 'ListByteMatchSetsRequest$NextMarker' => '<p>If you specify a value for <code>Limit</code> and you have more <code>ByteMatchSets</code> than the value of <code>Limit</code>, AWS WAF returns a <code>NextMarker</code> value in the response that allows you to list another group of <code>ByteMatchSets</code>. For the second and subsequent <code>ListByteMatchSets</code> requests, specify the value of <code>NextMarker</code> from the previous response to get information about another batch of <code>ByteMatchSets</code>.</p>', 'ListByteMatchSetsResponse$NextMarker' => '<p>If you have more <code>ByteMatchSet</code> objects than the number that you specified for <code>Limit</code> in the request, the response includes a <code>NextMarker</code> value. To list more <code>ByteMatchSet</code> objects, submit another <code>ListByteMatchSets</code> request, and specify the <code>NextMarker</code> value from the response in the <code>NextMarker</code> value in the next request.</p>', 'ListIPSetsRequest$NextMarker' => '<p>If you specify a value for <code>Limit</code> and you have more <code>IPSets</code> than the value of <code>Limit</code>, AWS WAF returns a <code>NextMarker</code> value in the response that allows you to list another group of <code>IPSets</code>. For the second and subsequent <code>ListIPSets</code> requests, specify the value of <code>NextMarker</code> from the previous response to get information about another batch of <code>ByteMatchSets</code>.</p>', 'ListIPSetsResponse$NextMarker' => '<p>If you have more <code>IPSet</code> objects than the number that you specified for <code>Limit</code> in the request, the response includes a <code>NextMarker</code> value. To list more <code>IPSet</code> objects, submit another <code>ListIPSets</code> request, and specify the <code>NextMarker</code> value from the response in the <code>NextMarker</code> value in the next request.</p>', 'ListRulesRequest$NextMarker' => '<p>If you specify a value for <code>Limit</code> and you have more <code>Rules</code> than the value of <code>Limit</code>, AWS WAF returns a <code>NextMarker</code> value in the response that allows you to list another group of <code>Rules</code>. For the second and subsequent <code>ListRules</code> requests, specify the value of <code>NextMarker</code> from the previous response to get information about another batch of <code>Rules</code>.</p>', 'ListRulesResponse$NextMarker' => '<p>If you have more <code>Rules</code> than the number that you specified for <code>Limit</code> in the request, the response includes a <code>NextMarker</code> value. To list more <code>Rules</code>, submit another <code>ListRules</code> request, and specify the <code>NextMarker</code> value from the response in the <code>NextMarker</code> value in the next request.</p>', 'ListSizeConstraintSetsRequest$NextMarker' => '<p>If you specify a value for <code>Limit</code> and you have more <code>SizeConstraintSets</code> than the value of <code>Limit</code>, AWS WAF returns a <code>NextMarker</code> value in the response that allows you to list another group of <code>SizeConstraintSets</code>. For the second and subsequent <code>ListSizeConstraintSets</code> requests, specify the value of <code>NextMarker</code> from the previous response to get information about another batch of <code>SizeConstraintSets</code>.</p>', 'ListSizeConstraintSetsResponse$NextMarker' => '<p>If you have more <code>SizeConstraintSet</code> objects than the number that you specified for <code>Limit</code> in the request, the response includes a <code>NextMarker</code> value. To list more <code>SizeConstraintSet</code> objects, submit another <code>ListSizeConstraintSets</code> request, and specify the <code>NextMarker</code> value from the response in the <code>NextMarker</code> value in the next request.</p>', 'ListSqlInjectionMatchSetsRequest$NextMarker' => '<p>If you specify a value for <code>Limit</code> and you have more <a>SqlInjectionMatchSet</a> objects than the value of <code>Limit</code>, AWS WAF returns a <code>NextMarker</code> value in the response that allows you to list another group of <code>SqlInjectionMatchSets</code>. For the second and subsequent <code>ListSqlInjectionMatchSets</code> requests, specify the value of <code>NextMarker</code> from the previous response to get information about another batch of <code>SqlInjectionMatchSets</code>.</p>', 'ListSqlInjectionMatchSetsResponse$NextMarker' => '<p>If you have more <a>SqlInjectionMatchSet</a> objects than the number that you specified for <code>Limit</code> in the request, the response includes a <code>NextMarker</code> value. To list more <code>SqlInjectionMatchSet</code> objects, submit another <code>ListSqlInjectionMatchSets</code> request, and specify the <code>NextMarker</code> value from the response in the <code>NextMarker</code> value in the next request.</p>', 'ListWebACLsRequest$NextMarker' => '<p>If you specify a value for <code>Limit</code> and you have more <code>WebACL</code> objects than the number that you specify for <code>Limit</code>, AWS WAF returns a <code>NextMarker</code> value in the response that allows you to list another group of <code>WebACL</code> objects. For the second and subsequent <code>ListWebACLs</code> requests, specify the value of <code>NextMarker</code> from the previous response to get information about another batch of <code>WebACL</code> objects.</p>', 'ListWebACLsResponse$NextMarker' => '<p>If you have more <code>WebACL</code> objects than the number that you specified for <code>Limit</code> in the request, the response includes a <code>NextMarker</code> value. To list more <code>WebACL</code> objects, submit another <code>ListWebACLs</code> request, and specify the <code>NextMarker</code> value from the response in the <code>NextMarker</code> value in the next request.</p>', 'ListXssMatchSetsRequest$NextMarker' => '<p>If you specify a value for <code>Limit</code> and you have more <a>XssMatchSet</a> objects than the value of <code>Limit</code>, AWS WAF returns a <code>NextMarker</code> value in the response that allows you to list another group of <code>XssMatchSets</code>. For the second and subsequent <code>ListXssMatchSets</code> requests, specify the value of <code>NextMarker</code> from the previous response to get information about another batch of <code>XssMatchSets</code>.</p>', 'ListXssMatchSetsResponse$NextMarker' => '<p>If you have more <a>XssMatchSet</a> objects than the number that you specified for <code>Limit</code> in the request, the response includes a <code>NextMarker</code> value. To list more <code>XssMatchSet</code> objects, submit another <code>ListXssMatchSets</code> request, and specify the <code>NextMarker</code> value from the response in the <code>NextMarker</code> value in the next request.</p>', ], ], 'PaginationLimit' => [ 'base' => NULL, 'refs' => [ 'ListByteMatchSetsRequest$Limit' => '<p>Specifies the number of <code>ByteMatchSet</code> objects that you want AWS WAF to return for this request. If you have more <code>ByteMatchSets</code> objects than the number you specify for <code>Limit</code>, the response includes a <code>NextMarker</code> value that you can use to get another batch of <code>ByteMatchSet</code> objects.</p>', 'ListIPSetsRequest$Limit' => '<p>Specifies the number of <code>IPSet</code> objects that you want AWS WAF to return for this request. If you have more <code>IPSet</code> objects than the number you specify for <code>Limit</code>, the response includes a <code>NextMarker</code> value that you can use to get another batch of <code>IPSet</code> objects.</p>', 'ListRulesRequest$Limit' => '<p>Specifies the number of <code>Rules</code> that you want AWS WAF to return for this request. If you have more <code>Rules</code> than the number that you specify for <code>Limit</code>, the response includes a <code>NextMarker</code> value that you can use to get another batch of <code>Rules</code>.</p>', 'ListSizeConstraintSetsRequest$Limit' => '<p>Specifies the number of <code>SizeConstraintSet</code> objects that you want AWS WAF to return for this request. If you have more <code>SizeConstraintSets</code> objects than the number you specify for <code>Limit</code>, the response includes a <code>NextMarker</code> value that you can use to get another batch of <code>SizeConstraintSet</code> objects.</p>', 'ListSqlInjectionMatchSetsRequest$Limit' => '<p>Specifies the number of <a>SqlInjectionMatchSet</a> objects that you want AWS WAF to return for this request. If you have more <code>SqlInjectionMatchSet</code> objects than the number you specify for <code>Limit</code>, the response includes a <code>NextMarker</code> value that you can use to get another batch of <code>Rules</code>.</p>', 'ListWebACLsRequest$Limit' => '<p>Specifies the number of <code>WebACL</code> objects that you want AWS WAF to return for this request. If you have more <code>WebACL</code> objects than the number that you specify for <code>Limit</code>, the response includes a <code>NextMarker</code> value that you can use to get another batch of <code>WebACL</code> objects.</p>', 'ListXssMatchSetsRequest$Limit' => '<p>Specifies the number of <a>XssMatchSet</a> objects that you want AWS WAF to return for this request. If you have more <code>XssMatchSet</code> objects than the number you specify for <code>Limit</code>, the response includes a <code>NextMarker</code> value that you can use to get another batch of <code>Rules</code>.</p>', ], ], 'ParameterExceptionField' => [ 'base' => NULL, 'refs' => [ 'WAFInvalidParameterException$field' => NULL, ], ], 'ParameterExceptionParameter' => [ 'base' => NULL, 'refs' => [ 'WAFInvalidParameterException$parameter' => NULL, ], ], 'ParameterExceptionReason' => [ 'base' => NULL, 'refs' => [ 'WAFInvalidParameterException$reason' => NULL, ], ], 'PopulationSize' => [ 'base' => NULL, 'refs' => [ 'GetSampledRequestsResponse$PopulationSize' => '<p>The total number of requests from which <code>GetSampledRequests</code> got a sample of <code>MaxItems</code> requests. If <code>PopulationSize</code> is less than <code>MaxItems</code>, the sample includes every request that your AWS resource received during the specified time range.</p>', ], ], 'PositionalConstraint' => [ 'base' => NULL, 'refs' => [ 'ByteMatchTuple$PositionalConstraint' => '<p>Within the portion of a web request that you want to search (for example, in the query string, if any), specify where you want AWS WAF to search. Valid values include the following:</p> <p><b>CONTAINS</b></p> <p>The specified part of the web request must include the value of <code>TargetString</code>, but the location doesn\'t matter.</p> <p><b>CONTAINS_WORD</b></p> <p>The specified part of the web request must include the value of <code>TargetString</code>, and <code>TargetString</code> must contain only alphanumeric characters or underscore (A-Z, a-z, 0-9, or _). In addition, <code>TargetString</code> must be a word, which means one of the following:</p> <ul> <li><code>TargetString</code> exactly matches the value of the specified part of the web request, such as the value of a header.</li> <li><code>TargetString</code> is at the beginning of the specified part of the web request and is followed by a character other than an alphanumeric character or underscore (_), for example, <code>BadBot;</code>.</li> <li><code>TargetString</code> is at the end of the specified part of the web request and is preceded by a character other than an alphanumeric character or underscore (_), for example, <code>;BadBot</code>.</li> <li><code>TargetString</code> is in the middle of the specified part of the web request and is preceded and followed by characters other than alphanumeric characters or underscore (_), for example, <code>-BadBot;</code>.</li> </ul> <p><b>EXACTLY</b></p> <p>The value of the specified part of the web request must exactly match the value of <code>TargetString</code>.</p> <p><b>STARTS_WITH</b></p> <p>The value of <code>TargetString</code> must appear at the beginning of the specified part of the web request.</p> <p><b>ENDS_WITH</b></p> <p>The value of <code>TargetString</code> must appear at the end of the specified part of the web request.</p>', ], ], 'Predicate' => [ 'base' => '<p>Specifies the <a>ByteMatchSet</a>, <a>IPSet</a>, <a>SqlInjectionMatchSet</a>, <a>XssMatchSet</a>, and <a>SizeConstraintSet</a> objects that you want to add to a <code>Rule</code> and, for each object, indicates whether you want to negate the settings, for example, requests that do NOT originate from the IP address 192.0.2.44. </p>', 'refs' => [ 'Predicates$member' => NULL, 'RuleUpdate$Predicate' => '<p>The ID of the <code>Predicate</code> (such as an <code>IPSet</code>) that you want to add to a <code>Rule</code>.</p>', ], ], 'PredicateType' => [ 'base' => NULL, 'refs' => [ 'Predicate$Type' => '<p>The type of predicate in a <code>Rule</code>, such as <code>ByteMatchSet</code> or <code>IPSet</code>.</p>', ], ], 'Predicates' => [ 'base' => NULL, 'refs' => [ 'Rule$Predicates' => '<p>The <code>Predicates</code> object contains one <code>Predicate</code> element for each <a>ByteMatchSet</a>, <a>IPSet</a>, or <a>SqlInjectionMatchSet</a> object that you want to include in a <code>Rule</code>.</p>', ], ], 'ResourceId' => [ 'base' => NULL, 'refs' => [ 'ActivatedRule$RuleId' => '<p>The <code>RuleId</code> for a <code>Rule</code>. You use <code>RuleId</code> to get more information about a <code>Rule</code> (see <a>GetRule</a>), update a <code>Rule</code> (see <a>UpdateRule</a>), insert a <code>Rule</code> into a <code>WebACL</code> or delete a one from a <code>WebACL</code> (see <a>UpdateWebACL</a>), or delete a <code>Rule</code> from AWS WAF (see <a>DeleteRule</a>).</p> <p><code>RuleId</code> is returned by <a>CreateRule</a> and by <a>ListRules</a>.</p>', 'ByteMatchSet$ByteMatchSetId' => '<p>The <code>ByteMatchSetId</code> for a <code>ByteMatchSet</code>. You use <code>ByteMatchSetId</code> to get information about a <code>ByteMatchSet</code> (see <a>GetByteMatchSet</a>), update a <code>ByteMatchSet</code> (see <a>UpdateByteMatchSet</a>), insert a <code>ByteMatchSet</code> into a <code>Rule</code> or delete one from a <code>Rule</code> (see <a>UpdateRule</a>), and delete a <code>ByteMatchSet</code> from AWS WAF (see <a>DeleteByteMatchSet</a>).</p> <p><code>ByteMatchSetId</code> is returned by <a>CreateByteMatchSet</a> and by <a>ListByteMatchSets</a>.</p>', 'ByteMatchSetSummary$ByteMatchSetId' => '<p>The <code>ByteMatchSetId</code> for a <code>ByteMatchSet</code>. You use <code>ByteMatchSetId</code> to get information about a <code>ByteMatchSet</code>, update a <code>ByteMatchSet</code>, remove a <code>ByteMatchSet</code> from a <code>Rule</code>, and delete a <code>ByteMatchSet</code> from AWS WAF.</p> <p><code>ByteMatchSetId</code> is returned by <a>CreateByteMatchSet</a> and by <a>ListByteMatchSets</a>.</p>', 'DeleteByteMatchSetRequest$ByteMatchSetId' => '<p>The <code>ByteMatchSetId</code> of the <a>ByteMatchSet</a> that you want to delete. <code>ByteMatchSetId</code> is returned by <a>CreateByteMatchSet</a> and by <a>ListByteMatchSets</a>.</p>', 'DeleteIPSetRequest$IPSetId' => '<p>The <code>IPSetId</code> of the <a>IPSet</a> that you want to delete. <code>IPSetId</code> is returned by <a>CreateIPSet</a> and by <a>ListIPSets</a>.</p>', 'DeleteRuleRequest$RuleId' => '<p>The <code>RuleId</code> of the <a>Rule</a> that you want to delete. <code>RuleId</code> is returned by <a>CreateRule</a> and by <a>ListRules</a>.</p>', 'DeleteSizeConstraintSetRequest$SizeConstraintSetId' => '<p>The <code>SizeConstraintSetId</code> of the <a>SizeConstraintSet</a> that you want to delete. <code>SizeConstraintSetId</code> is returned by <a>CreateSizeConstraintSet</a> and by <a>ListSizeConstraintSets</a>.</p>', 'DeleteSqlInjectionMatchSetRequest$SqlInjectionMatchSetId' => '<p>The <code>SqlInjectionMatchSetId</code> of the <a>SqlInjectionMatchSet</a> that you want to delete. <code>SqlInjectionMatchSetId</code> is returned by <a>CreateSqlInjectionMatchSet</a> and by <a>ListSqlInjectionMatchSets</a>.</p>', 'DeleteWebACLRequest$WebACLId' => '<p>The <code>WebACLId</code> of the <a>WebACL</a> that you want to delete. <code>WebACLId</code> is returned by <a>CreateWebACL</a> and by <a>ListWebACLs</a>.</p>', 'DeleteXssMatchSetRequest$XssMatchSetId' => '<p>The <code>XssMatchSetId</code> of the <a>XssMatchSet</a> that you want to delete. <code>XssMatchSetId</code> is returned by <a>CreateXssMatchSet</a> and by <a>ListXssMatchSets</a>.</p>', 'GetByteMatchSetRequest$ByteMatchSetId' => '<p>The <code>ByteMatchSetId</code> of the <a>ByteMatchSet</a> that you want to get. <code>ByteMatchSetId</code> is returned by <a>CreateByteMatchSet</a> and by <a>ListByteMatchSets</a>.</p>', 'GetIPSetRequest$IPSetId' => '<p>The <code>IPSetId</code> of the <a>IPSet</a> that you want to get. <code>IPSetId</code> is returned by <a>CreateIPSet</a> and by <a>ListIPSets</a>.</p>', 'GetRuleRequest$RuleId' => '<p>The <code>RuleId</code> of the <a>Rule</a> that you want to get. <code>RuleId</code> is returned by <a>CreateRule</a> and by <a>ListRules</a>.</p>', 'GetSampledRequestsRequest$WebAclId' => '<p>The <code>WebACLId</code> of the <code>WebACL</code> for which you want <code>GetSampledRequests</code> to return a sample of requests.</p>', 'GetSampledRequestsRequest$RuleId' => '<p><code>RuleId</code> is one of two values:</p> <ul> <li>The <code>RuleId</code> of the <code>Rule</code> for which you want <code>GetSampledRequests</code> to return a sample of requests.</li> <li><code>Default_Action</code>, which causes <code>GetSampledRequests</code> to return a sample of the requests that didn\'t match any of the rules in the specified <code>WebACL</code>.</li> </ul>', 'GetSizeConstraintSetRequest$SizeConstraintSetId' => '<p>The <code>SizeConstraintSetId</code> of the <a>SizeConstraintSet</a> that you want to get. <code>SizeConstraintSetId</code> is returned by <a>CreateSizeConstraintSet</a> and by <a>ListSizeConstraintSets</a>.</p>', 'GetSqlInjectionMatchSetRequest$SqlInjectionMatchSetId' => '<p>The <code>SqlInjectionMatchSetId</code> of the <a>SqlInjectionMatchSet</a> that you want to get. <code>SqlInjectionMatchSetId</code> is returned by <a>CreateSqlInjectionMatchSet</a> and by <a>ListSqlInjectionMatchSets</a>.</p>', 'GetWebACLRequest$WebACLId' => '<p>The <code>WebACLId</code> of the <a>WebACL</a> that you want to get. <code>WebACLId</code> is returned by <a>CreateWebACL</a> and by <a>ListWebACLs</a>.</p>', 'GetXssMatchSetRequest$XssMatchSetId' => '<p>The <code>XssMatchSetId</code> of the <a>XssMatchSet</a> that you want to get. <code>XssMatchSetId</code> is returned by <a>CreateXssMatchSet</a> and by <a>ListXssMatchSets</a>.</p>', 'IPSet$IPSetId' => '<p>The <code>IPSetId</code> for an <code>IPSet</code>. You use <code>IPSetId</code> to get information about an <code>IPSet</code> (see <a>GetIPSet</a>), update an <code>IPSet</code> (see <a>UpdateIPSet</a>), insert an <code>IPSet</code> into a <code>Rule</code> or delete one from a <code>Rule</code> (see <a>UpdateRule</a>), and delete an <code>IPSet</code> from AWS WAF (see <a>DeleteIPSet</a>).</p> <p><code>IPSetId</code> is returned by <a>CreateIPSet</a> and by <a>ListIPSets</a>.</p>', 'IPSetSummary$IPSetId' => '<p>The <code>IPSetId</code> for an <a>IPSet</a>. You can use <code>IPSetId</code> in a <a>GetIPSet</a> request to get detailed information about an <a>IPSet</a>.</p>', 'Predicate$DataId' => '<p>A unique identifier for a predicate in a <code>Rule</code>, such as <code>ByteMatchSetId</code> or <code>IPSetId</code>. The ID is returned by the corresponding <code>Create</code> or <code>List</code> command.</p>', 'Rule$RuleId' => '<p>A unique identifier for a <code>Rule</code>. You use <code>RuleId</code> to get more information about a <code>Rule</code> (see <a>GetRule</a>), update a <code>Rule</code> (see <a>UpdateRule</a>), insert a <code>Rule</code> into a <code>WebACL</code> or delete a one from a <code>WebACL</code> (see <a>UpdateWebACL</a>), or delete a <code>Rule</code> from AWS WAF (see <a>DeleteRule</a>).</p> <p><code>RuleId</code> is returned by <a>CreateRule</a> and by <a>ListRules</a>.</p>', 'RuleSummary$RuleId' => '<p>A unique identifier for a <code>Rule</code>. You use <code>RuleId</code> to get more information about a <code>Rule</code> (see <a>GetRule</a>), update a <code>Rule</code> (see <a>UpdateRule</a>), insert a <code>Rule</code> into a <code>WebACL</code> or delete one from a <code>WebACL</code> (see <a>UpdateWebACL</a>), or delete a <code>Rule</code> from AWS WAF (see <a>DeleteRule</a>).</p> <p><code>RuleId</code> is returned by <a>CreateRule</a> and by <a>ListRules</a>.</p>', 'SizeConstraintSet$SizeConstraintSetId' => '<p>A unique identifier for a <code>SizeConstraintSet</code>. You use <code>SizeConstraintSetId</code> to get information about a <code>SizeConstraintSet</code> (see <a>GetSizeConstraintSet</a>), update a <code>SizeConstraintSet</code> (see <a>UpdateSizeConstraintSet</a>), insert a <code>SizeConstraintSet</code> into a <code>Rule</code> or delete one from a <code>Rule</code> (see <a>UpdateRule</a>), and delete a <code>SizeConstraintSet</code> from AWS WAF (see <a>DeleteSizeConstraintSet</a>).</p> <p><code>SizeConstraintSetId</code> is returned by <a>CreateSizeConstraintSet</a> and by <a>ListSizeConstraintSets</a>.</p>', 'SizeConstraintSetSummary$SizeConstraintSetId' => '<p>A unique identifier for a <code>SizeConstraintSet</code>. You use <code>SizeConstraintSetId</code> to get information about a <code>SizeConstraintSet</code> (see <a>GetSizeConstraintSet</a>), update a <code>SizeConstraintSet</code> (see <a>UpdateSizeConstraintSet</a>), insert a <code>SizeConstraintSet</code> into a <code>Rule</code> or delete one from a <code>Rule</code> (see <a>UpdateRule</a>), and delete a <code>SizeConstraintSet</code> from AWS WAF (see <a>DeleteSizeConstraintSet</a>).</p> <p><code>SizeConstraintSetId</code> is returned by <a>CreateSizeConstraintSet</a> and by <a>ListSizeConstraintSets</a>.</p>', 'SqlInjectionMatchSet$SqlInjectionMatchSetId' => '<p>A unique identifier for a <code>SqlInjectionMatchSet</code>. You use <code>SqlInjectionMatchSetId</code> to get information about a <code>SqlInjectionMatchSet</code> (see <a>GetSqlInjectionMatchSet</a>), update a <code>SqlInjectionMatchSet</code> (see <a>UpdateSqlInjectionMatchSet</a>), insert a <code>SqlInjectionMatchSet</code> into a <code>Rule</code> or delete one from a <code>Rule</code> (see <a>UpdateRule</a>), and delete a <code>SqlInjectionMatchSet</code> from AWS WAF (see <a>DeleteSqlInjectionMatchSet</a>).</p> <p><code>SqlInjectionMatchSetId</code> is returned by <a>CreateSqlInjectionMatchSet</a> and by <a>ListSqlInjectionMatchSets</a>.</p>', 'SqlInjectionMatchSetSummary$SqlInjectionMatchSetId' => '<p>A unique identifier for a <code>SqlInjectionMatchSet</code>. You use <code>SqlInjectionMatchSetId</code> to get information about a <code>SqlInjectionMatchSet</code> (see <a>GetSqlInjectionMatchSet</a>), update a <code>SqlInjectionMatchSet</code> (see <a>UpdateSqlInjectionMatchSet</a>), insert a <code>SqlInjectionMatchSet</code> into a <code>Rule</code> or delete one from a <code>Rule</code> (see <a>UpdateRule</a>), and delete a <code>SqlInjectionMatchSet</code> from AWS WAF (see <a>DeleteSqlInjectionMatchSet</a>).</p> <p><code>SqlInjectionMatchSetId</code> is returned by <a>CreateSqlInjectionMatchSet</a> and by <a>ListSqlInjectionMatchSets</a>.</p>', 'UpdateByteMatchSetRequest$ByteMatchSetId' => '<p>The <code>ByteMatchSetId</code> of the <a>ByteMatchSet</a> that you want to update. <code>ByteMatchSetId</code> is returned by <a>CreateByteMatchSet</a> and by <a>ListByteMatchSets</a>.</p>', 'UpdateIPSetRequest$IPSetId' => '<p>The <code>IPSetId</code> of the <a>IPSet</a> that you want to update. <code>IPSetId</code> is returned by <a>CreateIPSet</a> and by <a>ListIPSets</a>.</p>', 'UpdateRuleRequest$RuleId' => '<p>The <code>RuleId</code> of the <code>Rule</code> that you want to update. <code>RuleId</code> is returned by <code>CreateRule</code> and by <a>ListRules</a>.</p>', 'UpdateSizeConstraintSetRequest$SizeConstraintSetId' => '<p>The <code>SizeConstraintSetId</code> of the <a>SizeConstraintSet</a> that you want to update. <code>SizeConstraintSetId</code> is returned by <a>CreateSizeConstraintSet</a> and by <a>ListSizeConstraintSets</a>.</p>', 'UpdateSqlInjectionMatchSetRequest$SqlInjectionMatchSetId' => '<p>The <code>SqlInjectionMatchSetId</code> of the <code>SqlInjectionMatchSet</code> that you want to update. <code>SqlInjectionMatchSetId</code> is returned by <a>CreateSqlInjectionMatchSet</a> and by <a>ListSqlInjectionMatchSets</a>.</p>', 'UpdateWebACLRequest$WebACLId' => '<p>The <code>WebACLId</code> of the <a>WebACL</a> that you want to update. <code>WebACLId</code> is returned by <a>CreateWebACL</a> and by <a>ListWebACLs</a>.</p>', 'UpdateXssMatchSetRequest$XssMatchSetId' => '<p>The <code>XssMatchSetId</code> of the <code>XssMatchSet</code> that you want to update. <code>XssMatchSetId</code> is returned by <a>CreateXssMatchSet</a> and by <a>ListXssMatchSets</a>.</p>', 'WebACL$WebACLId' => '<p>A unique identifier for a <code>WebACL</code>. You use <code>WebACLId</code> to get information about a <code>WebACL</code> (see <a>GetWebACL</a>), update a <code>WebACL</code> (see <a>UpdateWebACL</a>), and delete a <code>WebACL</code> from AWS WAF (see <a>DeleteWebACL</a>).</p> <p><code>WebACLId</code> is returned by <a>CreateWebACL</a> and by <a>ListWebACLs</a>.</p>', 'WebACLSummary$WebACLId' => '<p>A unique identifier for a <code>WebACL</code>. You use <code>WebACLId</code> to get information about a <code>WebACL</code> (see <a>GetWebACL</a>), update a <code>WebACL</code> (see <a>UpdateWebACL</a>), and delete a <code>WebACL</code> from AWS WAF (see <a>DeleteWebACL</a>).</p> <p><code>WebACLId</code> is returned by <a>CreateWebACL</a> and by <a>ListWebACLs</a>.</p>', 'XssMatchSet$XssMatchSetId' => '<p>A unique identifier for an <code>XssMatchSet</code>. You use <code>XssMatchSetId</code> to get information about an <code>XssMatchSet</code> (see <a>GetXssMatchSet</a>), update an <code>XssMatchSet</code> (see <a>UpdateXssMatchSet</a>), insert an <code>XssMatchSet</code> into a <code>Rule</code> or delete one from a <code>Rule</code> (see <a>UpdateRule</a>), and delete an <code>XssMatchSet</code> from AWS WAF (see <a>DeleteXssMatchSet</a>).</p> <p><code>XssMatchSetId</code> is returned by <a>CreateXssMatchSet</a> and by <a>ListXssMatchSets</a>.</p>', 'XssMatchSetSummary$XssMatchSetId' => '<p>A unique identifier for an <code>XssMatchSet</code>. You use <code>XssMatchSetId</code> to get information about a <code>XssMatchSet</code> (see <a>GetXssMatchSet</a>), update an <code>XssMatchSet</code> (see <a>UpdateXssMatchSet</a>), insert an <code>XssMatchSet</code> into a <code>Rule</code> or delete one from a <code>Rule</code> (see <a>UpdateRule</a>), and delete an <code>XssMatchSet</code> from AWS WAF (see <a>DeleteXssMatchSet</a>).</p> <p><code>XssMatchSetId</code> is returned by <a>CreateXssMatchSet</a> and by <a>ListXssMatchSets</a>.</p>', ], ], 'ResourceName' => [ 'base' => NULL, 'refs' => [ 'ByteMatchSet$Name' => '<p>A friendly name or description of the <a>ByteMatchSet</a>. You can\'t change <code>Name</code> after you create a <code>ByteMatchSet</code>.</p>', 'ByteMatchSetSummary$Name' => '<p>A friendly name or description of the <a>ByteMatchSet</a>. You can\'t change <code>Name</code> after you create a <code>ByteMatchSet</code>.</p>', 'CreateByteMatchSetRequest$Name' => '<p>A friendly name or description of the <a>ByteMatchSet</a>. You can\'t change <code>Name</code> after you create a <code>ByteMatchSet</code>.</p>', 'CreateIPSetRequest$Name' => '<p>A friendly name or description of the <a>IPSet</a>. You can\'t change <code>Name</code> after you create the <code>IPSet</code>.</p>', 'CreateRuleRequest$Name' => '<p>A friendly name or description of the <a>Rule</a>. You can\'t change the name of a <code>Rule</code> after you create it.</p>', 'CreateSizeConstraintSetRequest$Name' => '<p>A friendly name or description of the <a>SizeConstraintSet</a>. You can\'t change <code>Name</code> after you create a <code>SizeConstraintSet</code>.</p>', 'CreateSqlInjectionMatchSetRequest$Name' => '<p>A friendly name or description for the <a>SqlInjectionMatchSet</a> that you\'re creating. You can\'t change <code>Name</code> after you create the <code>SqlInjectionMatchSet</code>.</p>', 'CreateWebACLRequest$Name' => '<p>A friendly name or description of the <a>WebACL</a>. You can\'t change <code>Name</code> after you create the <code>WebACL</code>.</p>', 'CreateXssMatchSetRequest$Name' => '<p>A friendly name or description for the <a>XssMatchSet</a> that you\'re creating. You can\'t change <code>Name</code> after you create the <code>XssMatchSet</code>.</p>', 'IPSet$Name' => '<p>A friendly name or description of the <a>IPSet</a>. You can\'t change the name of an <code>IPSet</code> after you create it.</p>', 'IPSetSummary$Name' => '<p>A friendly name or description of the <a>IPSet</a>. You can\'t change the name of an <code>IPSet</code> after you create it.</p>', 'Rule$Name' => '<p>The friendly name or description for the <code>Rule</code>. You can\'t change the name of a <code>Rule</code> after you create it.</p>', 'RuleSummary$Name' => '<p>A friendly name or description of the <a>Rule</a>. You can\'t change the name of a <code>Rule</code> after you create it.</p>', 'SizeConstraintSet$Name' => '<p>The name, if any, of the <code>SizeConstraintSet</code>.</p>', 'SizeConstraintSetSummary$Name' => '<p>The name of the <code>SizeConstraintSet</code>, if any.</p>', 'SqlInjectionMatchSet$Name' => '<p>The name, if any, of the <code>SqlInjectionMatchSet</code>.</p>', 'SqlInjectionMatchSetSummary$Name' => '<p>The name of the <code>SqlInjectionMatchSet</code>, if any, specified by <code>Id</code>.</p>', 'WebACL$Name' => '<p>A friendly name or description of the <code>WebACL</code>. You can\'t change the name of a <code>WebACL</code> after you create it.</p>', 'WebACLSummary$Name' => '<p>A friendly name or description of the <a>WebACL</a>. You can\'t change the name of a <code>WebACL</code> after you create it.</p>', 'XssMatchSet$Name' => '<p>The name, if any, of the <code>XssMatchSet</code>.</p>', 'XssMatchSetSummary$Name' => '<p>The name of the <code>XssMatchSet</code>, if any, specified by <code>Id</code>.</p>', ], ], 'Rule' => [ 'base' => '<p>A combination of <a>ByteMatchSet</a>, <a>IPSet</a>, and/or <a>SqlInjectionMatchSet</a> objects that identify the web requests that you want to allow, block, or count. For example, you might create a <code>Rule</code> that includes the following predicates:</p> <ul> <li>An <code>IPSet</code> that causes AWS WAF to search for web requests that originate from the IP address <code>192.0.2.44</code></li> <li>A <code>ByteMatchSet</code> that causes AWS WAF to search for web requests for which the value of the <code>User-Agent</code> header is <code>BadBot</code>.</li> </ul> <p>To match the settings in this <code>Rule</code>, a request must originate from <code>192.0.2.44</code> AND include a <code>User-Agent</code> header for which the value is <code>BadBot</code>.</p>', 'refs' => [ 'CreateRuleResponse$Rule' => '<p>The <a>Rule</a> returned in the <code>CreateRule</code> response.</p>', 'GetRuleResponse$Rule' => '<p>Information about the <a>Rule</a> that you specified in the <code>GetRule</code> request. For more information, see the following topics:</p> <ul> <li><a>Rule</a>: Contains <code>MetricName</code>, <code>Name</code>, an array of <code>Predicate</code> objects, and <code>RuleId</code></li> <li><a>Predicate</a>: Each <code>Predicate</code> object contains <code>DataId</code>, <code>Negated</code>, and <code>Type</code></li> </ul>', ], ], 'RulePriority' => [ 'base' => NULL, 'refs' => [ 'ActivatedRule$Priority' => '<p>Specifies the order in which the <code>Rules</code> in a <code>WebACL</code> are evaluated. Rules with a lower value for <code>Priority</code> are evaluated before <code>Rules</code> with a higher value. The value must be a unique integer. If you add multiple <code>Rules</code> to a <code>WebACL</code>, the values don\'t need to be consecutive.</p>', ], ], 'RuleSummaries' => [ 'base' => NULL, 'refs' => [ 'ListRulesResponse$Rules' => '<p>An array of <a>RuleSummary</a> objects.</p>', ], ], 'RuleSummary' => [ 'base' => '<p>Contains the identifier and the friendly name or description of the <code>Rule</code>.</p>', 'refs' => [ 'RuleSummaries$member' => NULL, ], ], 'RuleUpdate' => [ 'base' => '<p>Specifies a <code>Predicate</code> (such as an <code>IPSet</code>) and indicates whether you want to add it to a <code>Rule</code> or delete it from a <code>Rule</code>.</p>', 'refs' => [ 'RuleUpdates$member' => NULL, ], ], 'RuleUpdates' => [ 'base' => NULL, 'refs' => [ 'UpdateRuleRequest$Updates' => '<p>An array of <code>RuleUpdate</code> objects that you want to insert into or delete from a <a>Rule</a>. For more information, see the applicable data types:</p> <ul> <li><a>RuleUpdate</a>: Contains <code>Action</code> and <code>Predicate</code></li> <li><a>Predicate</a>: Contains <code>DataId</code>, <code>Negated</code>, and <code>Type</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'SampleWeight' => [ 'base' => NULL, 'refs' => [ 'SampledHTTPRequest$Weight' => '<p>A value that indicates how one result in the response relates proportionally to other results in the response. A result that has a weight of <code>2</code> represents roughly twice as many CloudFront web requests as a result that has a weight of <code>1</code>.</p>', ], ], 'SampledHTTPRequest' => [ 'base' => '<p>The response from a <a>GetSampledRequests</a> request includes a <code>SampledHTTPRequests</code> complex type that appears as <code>SampledRequests</code> in the response syntax. <code>SampledHTTPRequests</code> contains one <code>SampledHTTPRequest</code> object for each web request that is returned by <code>GetSampledRequests</code>.</p>', 'refs' => [ 'SampledHTTPRequests$member' => NULL, ], ], 'SampledHTTPRequests' => [ 'base' => NULL, 'refs' => [ 'GetSampledRequestsResponse$SampledRequests' => '<p>A complex type that contains detailed information about each of the requests in the sample.</p>', ], ], 'Size' => [ 'base' => NULL, 'refs' => [ 'SizeConstraint$Size' => '<p>The size in bytes that you want AWS WAF to compare against the size of the specified <code>FieldToMatch</code>. AWS WAF uses this in combination with <code>ComparisonOperator</code> and <code>FieldToMatch</code> to build an expression in the form of "<code>Size</code> <code>ComparisonOperator</code> size in bytes of <code>FieldToMatch</code>". If that expression is true, the <code>SizeConstraint</code> is considered to match.</p> <p>Valid values for size are 0 - 21474836480 bytes (0 - 20 GB). </p> <p>If you specify <code>URI</code> for the value of <code>Type</code>, the / in the URI counts as one character. For example, the URI <code>/logo.jpg</code> is nine characters long.</p>', ], ], 'SizeConstraint' => [ 'base' => '<p>Specifies a constraint on the size of a part of the web request. AWS WAF uses the <code>Size</code>, <code>ComparisonOperator</code>, and <code>FieldToMatch</code> to build an expression in the form of "<code>Size</code> <code>ComparisonOperator</code> size in bytes of <code>FieldToMatch</code>". If that expression is true, the <code>SizeConstraint</code> is considered to match.</p>', 'refs' => [ 'SizeConstraintSetUpdate$SizeConstraint' => '<p>Specifies a constraint on the size of a part of the web request. AWS WAF uses the <code>Size</code>, <code>ComparisonOperator</code>, and <code>FieldToMatch</code> to build an expression in the form of "<code>Size</code> <code>ComparisonOperator</code> size in bytes of <code>FieldToMatch</code>". If that expression is true, the <code>SizeConstraint</code> is considered to match.</p>', 'SizeConstraints$member' => NULL, ], ], 'SizeConstraintSet' => [ 'base' => '<p>A complex type that contains <code>SizeConstraint</code> objects, which specify the parts of web requests that you want AWS WAF to inspect the size of. If a <code>SizeConstraintSet</code> contains more than one <code>SizeConstraint</code> object, a request only needs to match one constraint to be considered a match.</p>', 'refs' => [ 'CreateSizeConstraintSetResponse$SizeConstraintSet' => '<p>A <a>SizeConstraintSet</a> that contains no <code>SizeConstraint</code> objects.</p>', 'GetSizeConstraintSetResponse$SizeConstraintSet' => '<p>Information about the <a>SizeConstraintSet</a> that you specified in the <code>GetSizeConstraintSet</code> request. For more information, see the following topics:</p> <ul> <li><a>SizeConstraintSet</a>: Contains <code>SizeConstraintSetId</code>, <code>SizeConstraints</code>, and <code>Name</code></li> <li><code>SizeConstraints</code>: Contains an array of <a>SizeConstraint</a> objects. Each <code>SizeConstraint</code> object contains <a>FieldToMatch</a>, <code>TextTransformation</code>, <code>ComparisonOperator</code>, and <code>Size</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'SizeConstraintSetSummaries' => [ 'base' => NULL, 'refs' => [ 'ListSizeConstraintSetsResponse$SizeConstraintSets' => '<p>An array of <a>SizeConstraintSetSummary</a> objects.</p>', ], ], 'SizeConstraintSetSummary' => [ 'base' => '<p>The <code>Id</code> and <code>Name</code> of a <code>SizeConstraintSet</code>.</p>', 'refs' => [ 'SizeConstraintSetSummaries$member' => NULL, ], ], 'SizeConstraintSetUpdate' => [ 'base' => '<p>Specifies the part of a web request that you want to inspect the size of and indicates whether you want to add the specification to a <a>SizeConstraintSet</a> or delete it from a <code>SizeConstraintSet</code>.</p>', 'refs' => [ 'SizeConstraintSetUpdates$member' => NULL, ], ], 'SizeConstraintSetUpdates' => [ 'base' => NULL, 'refs' => [ 'UpdateSizeConstraintSetRequest$Updates' => '<p>An array of <code>SizeConstraintSetUpdate</code> objects that you want to insert into or delete from a <a>SizeConstraintSet</a>. For more information, see the applicable data types:</p> <ul> <li><a>SizeConstraintSetUpdate</a>: Contains <code>Action</code> and <code>SizeConstraint</code></li> <li><a>SizeConstraint</a>: Contains <code>FieldToMatch</code>, <code>TextTransformation</code>, <code>ComparisonOperator</code>, and <code>Size</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'SizeConstraints' => [ 'base' => NULL, 'refs' => [ 'SizeConstraintSet$SizeConstraints' => '<p>Specifies the parts of web requests that you want to inspect the size of.</p>', ], ], 'SqlInjectionMatchSet' => [ 'base' => '<p>A complex type that contains <code>SqlInjectionMatchTuple</code> objects, which specify the parts of web requests that you want AWS WAF to inspect for snippets of malicious SQL code and, if you want AWS WAF to inspect a header, the name of the header. If a <code>SqlInjectionMatchSet</code> contains more than one <code>SqlInjectionMatchTuple</code> object, a request needs to include snippets of SQL code in only one of the specified parts of the request to be considered a match.</p>', 'refs' => [ 'CreateSqlInjectionMatchSetResponse$SqlInjectionMatchSet' => '<p>A <a>SqlInjectionMatchSet</a>.</p>', 'GetSqlInjectionMatchSetResponse$SqlInjectionMatchSet' => '<p>Information about the <a>SqlInjectionMatchSet</a> that you specified in the <code>GetSqlInjectionMatchSet</code> request. For more information, see the following topics:</p> <ul> <li><a>SqlInjectionMatchSet</a>: Contains <code>Name</code>, <code>SqlInjectionMatchSetId</code>, and an array of <code>SqlInjectionMatchTuple</code> objects</li> <li><a>SqlInjectionMatchTuple</a>: Each <code>SqlInjectionMatchTuple</code> object contains <code>FieldToMatch</code> and <code>TextTransformation</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'SqlInjectionMatchSetSummaries' => [ 'base' => NULL, 'refs' => [ 'ListSqlInjectionMatchSetsResponse$SqlInjectionMatchSets' => '<p>An array of <a>SqlInjectionMatchSetSummary</a> objects.</p>', ], ], 'SqlInjectionMatchSetSummary' => [ 'base' => '<p>The <code>Id</code> and <code>Name</code> of a <code>SqlInjectionMatchSet</code>.</p>', 'refs' => [ 'SqlInjectionMatchSetSummaries$member' => NULL, ], ], 'SqlInjectionMatchSetUpdate' => [ 'base' => '<p>Specifies the part of a web request that you want to inspect for snippets of malicious SQL code and indicates whether you want to add the specification to a <a>SqlInjectionMatchSet</a> or delete it from a <code>SqlInjectionMatchSet</code>.</p>', 'refs' => [ 'SqlInjectionMatchSetUpdates$member' => NULL, ], ], 'SqlInjectionMatchSetUpdates' => [ 'base' => NULL, 'refs' => [ 'UpdateSqlInjectionMatchSetRequest$Updates' => '<p>An array of <code>SqlInjectionMatchSetUpdate</code> objects that you want to insert into or delete from a <a>SqlInjectionMatchSet</a>. For more information, see the applicable data types:</p> <ul> <li><a>SqlInjectionMatchSetUpdate</a>: Contains <code>Action</code> and <code>SqlInjectionMatchTuple</code></li> <li><a>SqlInjectionMatchTuple</a>: Contains <code>FieldToMatch</code> and <code>TextTransformation</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'SqlInjectionMatchTuple' => [ 'base' => '<p>Specifies the part of a web request that you want AWS WAF to inspect for snippets of malicious SQL code and, if you want AWS WAF to inspect a header, the name of the header.</p>', 'refs' => [ 'SqlInjectionMatchSetUpdate$SqlInjectionMatchTuple' => '<p>Specifies the part of a web request that you want AWS WAF to inspect for snippets of malicious SQL code and, if you want AWS WAF to inspect a header, the name of the header.</p>', 'SqlInjectionMatchTuples$member' => NULL, ], ], 'SqlInjectionMatchTuples' => [ 'base' => NULL, 'refs' => [ 'SqlInjectionMatchSet$SqlInjectionMatchTuples' => '<p>Specifies the parts of web requests that you want to inspect for snippets of malicious SQL code.</p>', ], ], 'TextTransformation' => [ 'base' => NULL, 'refs' => [ 'ByteMatchTuple$TextTransformation' => '<p>Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass AWS WAF. If you specify a transformation, AWS WAF performs the transformation on <code>TargetString</code> before inspecting a request for a match.</p> <p><b>CMD_LINE</b></p> <p>When you\'re concerned that attackers are injecting an operating system commandline command and using unusual formatting to disguise some or all of the command, use this option to perform the following transformations:</p> <ul> <li>Delete the following characters: \\ " \' ^</li> <li>Delete spaces before the following characters: / (</li> <li>Replace the following characters with a space: , ;</li> <li>Replace multiple spaces with one space</li> <li>Convert uppercase letters (A-Z) to lowercase (a-z)</li> </ul> <p><b>COMPRESS_WHITE_SPACE</b></p> <p>Use this option to replace the following characters with a space character (decimal 32):</p> <ul> <li>\\f, formfeed, decimal 12</li> <li>\\t, tab, decimal 9</li> <li>\\n, newline, decimal 10</li> <li>\\r, carriage return, decimal 13</li> <li>\\v, vertical tab, decimal 11</li> <li>non-breaking space, decimal 160</li> </ul> <p><code>COMPRESS_WHITE_SPACE</code> also replaces multiple spaces with one space.</p> <p><b>HTML_ENTITY_DECODE</b></p> <p>Use this option to replace HTML-encoded characters with unencoded characters. <code>HTML_ENTITY_DECODE</code> performs the following operations:</p> <ul> <li>Replaces <code>(ampersand)quot;</code> with <code>"</code></li> <li>Replaces <code>(ampersand)nbsp;</code> with a non-breaking space, decimal 160</li> <li>Replaces <code>(ampersand)lt;</code> with a "less than" symbol</li> <li>Replaces <code>(ampersand)gt;</code> with <code>></code></li> <li>Replaces characters that are represented in hexadecimal format, <code>(ampersand)#xhhhh;</code>, with the corresponding characters</li> <li>Replaces characters that are represented in decimal format, <code>(ampersand)#nnnn;</code>, with the corresponding characters</li> </ul> <p><b>LOWERCASE</b></p> <p>Use this option to convert uppercase letters (A-Z) to lowercase (a-z).</p> <p><b>URL_DECODE</b></p> <p>Use this option to decode a URL-encoded value.</p> <p><b>NONE</b></p> <p>Specify <code>NONE</code> if you don\'t want to perform any text transformations.</p>', 'SizeConstraint$TextTransformation' => '<p>Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass AWS WAF. If you specify a transformation, AWS WAF performs the transformation on <code>FieldToMatch</code> before inspecting a request for a match.</p> <p>Note that if you choose <code>BODY</code> for the value of <code>Type</code>, you must choose <code>NONE</code> for <code>TextTransformation</code> because CloudFront forwards only the first 8192 bytes for inspection. </p> <p><b>NONE</b></p> <p>Specify <code>NONE</code> if you don\'t want to perform any text transformations.</p> <p><b>CMD_LINE</b></p> <p>When you\'re concerned that attackers are injecting an operating system command line command and using unusual formatting to disguise some or all of the command, use this option to perform the following transformations:</p> <ul> <li>Delete the following characters: \\ " \' ^</li> <li>Delete spaces before the following characters: / (</li> <li>Replace the following characters with a space: , ;</li> <li>Replace multiple spaces with one space</li> <li>Convert uppercase letters (A-Z) to lowercase (a-z)</li> </ul> <p><b>COMPRESS_WHITE_SPACE</b></p> <p>Use this option to replace the following characters with a space character (decimal 32):</p> <ul> <li>\\f, formfeed, decimal 12</li> <li>\\t, tab, decimal 9</li> <li>\\n, newline, decimal 10</li> <li>\\r, carriage return, decimal 13</li> <li>\\v, vertical tab, decimal 11</li> <li>non-breaking space, decimal 160</li> </ul> <p><code>COMPRESS_WHITE_SPACE</code> also replaces multiple spaces with one space.</p> <p><b>HTML_ENTITY_DECODE</b></p> <p>Use this option to replace HTML-encoded characters with unencoded characters. <code>HTML_ENTITY_DECODE</code> performs the following operations:</p> <ul> <li>Replaces <code>(ampersand)quot;</code> with <code>"</code></li> <li>Replaces <code>(ampersand)nbsp;</code> with a non-breaking space, decimal 160</li> <li>Replaces <code>(ampersand)lt;</code> with a "less than" symbol</li> <li>Replaces <code>(ampersand)gt;</code> with <code>></code></li> <li>Replaces characters that are represented in hexadecimal format, <code>(ampersand)#xhhhh;</code>, with the corresponding characters</li> <li>Replaces characters that are represented in decimal format, <code>(ampersand)#nnnn;</code>, with the corresponding characters</li> </ul> <p><b>LOWERCASE</b></p> <p>Use this option to convert uppercase letters (A-Z) to lowercase (a-z).</p> <p><b>URL_DECODE</b></p> <p>Use this option to decode a URL-encoded value.</p>', 'SqlInjectionMatchTuple$TextTransformation' => '<p>Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass AWS WAF. If you specify a transformation, AWS WAF performs the transformation on <code>FieldToMatch</code> before inspecting a request for a match.</p> <p><b>CMD_LINE</b></p> <p>When you\'re concerned that attackers are injecting an operating system commandline command and using unusual formatting to disguise some or all of the command, use this option to perform the following transformations:</p> <ul> <li>Delete the following characters: \\ " \' ^</li> <li>Delete spaces before the following characters: / (</li> <li>Replace the following characters with a space: , ;</li> <li>Replace multiple spaces with one space</li> <li>Convert uppercase letters (A-Z) to lowercase (a-z)</li> </ul> <p><b>COMPRESS_WHITE_SPACE</b></p> <p>Use this option to replace the following characters with a space character (decimal 32):</p> <ul> <li>\\f, formfeed, decimal 12</li> <li>\\t, tab, decimal 9</li> <li>\\n, newline, decimal 10</li> <li>\\r, carriage return, decimal 13</li> <li>\\v, vertical tab, decimal 11</li> <li>non-breaking space, decimal 160</li> </ul> <p><code>COMPRESS_WHITE_SPACE</code> also replaces multiple spaces with one space.</p> <p><b>HTML_ENTITY_DECODE</b></p> <p>Use this option to replace HTML-encoded characters with unencoded characters. <code>HTML_ENTITY_DECODE</code> performs the following operations:</p> <ul> <li>Replaces <code>(ampersand)quot;</code> with <code>"</code></li> <li>Replaces <code>(ampersand)nbsp;</code> with a non-breaking space, decimal 160</li> <li>Replaces <code>(ampersand)lt;</code> with a "less than" symbol</li> <li>Replaces <code>(ampersand)gt;</code> with <code>></code></li> <li>Replaces characters that are represented in hexadecimal format, <code>(ampersand)#xhhhh;</code>, with the corresponding characters</li> <li>Replaces characters that are represented in decimal format, <code>(ampersand)#nnnn;</code>, with the corresponding characters</li> </ul> <p><b>LOWERCASE</b></p> <p>Use this option to convert uppercase letters (A-Z) to lowercase (a-z).</p> <p><b>URL_DECODE</b></p> <p>Use this option to decode a URL-encoded value.</p> <p><b>NONE</b></p> <p>Specify <code>NONE</code> if you don\'t want to perform any text transformations.</p>', 'XssMatchTuple$TextTransformation' => '<p>Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass AWS WAF. If you specify a transformation, AWS WAF performs the transformation on <code>FieldToMatch</code> before inspecting a request for a match.</p> <p><b>CMD_LINE</b></p> <p>When you\'re concerned that attackers are injecting an operating system commandline command and using unusual formatting to disguise some or all of the command, use this option to perform the following transformations:</p> <ul> <li>Delete the following characters: \\ " \' ^</li> <li>Delete spaces before the following characters: / (</li> <li>Replace the following characters with a space: , ;</li> <li>Replace multiple spaces with one space</li> <li>Convert uppercase letters (A-Z) to lowercase (a-z)</li> </ul> <p><b>COMPRESS_WHITE_SPACE</b></p> <p>Use this option to replace the following characters with a space character (decimal 32):</p> <ul> <li>\\f, formfeed, decimal 12</li> <li>\\t, tab, decimal 9</li> <li>\\n, newline, decimal 10</li> <li>\\r, carriage return, decimal 13</li> <li>\\v, vertical tab, decimal 11</li> <li>non-breaking space, decimal 160</li> </ul> <p><code>COMPRESS_WHITE_SPACE</code> also replaces multiple spaces with one space.</p> <p><b>HTML_ENTITY_DECODE</b></p> <p>Use this option to replace HTML-encoded characters with unencoded characters. <code>HTML_ENTITY_DECODE</code> performs the following operations:</p> <ul> <li>Replaces <code>(ampersand)quot;</code> with <code>"</code></li> <li>Replaces <code>(ampersand)nbsp;</code> with a non-breaking space, decimal 160</li> <li>Replaces <code>(ampersand)lt;</code> with a "less than" symbol</li> <li>Replaces <code>(ampersand)gt;</code> with <code>></code></li> <li>Replaces characters that are represented in hexadecimal format, <code>(ampersand)#xhhhh;</code>, with the corresponding characters</li> <li>Replaces characters that are represented in decimal format, <code>(ampersand)#nnnn;</code>, with the corresponding characters</li> </ul> <p><b>LOWERCASE</b></p> <p>Use this option to convert uppercase letters (A-Z) to lowercase (a-z).</p> <p><b>URL_DECODE</b></p> <p>Use this option to decode a URL-encoded value.</p> <p><b>NONE</b></p> <p>Specify <code>NONE</code> if you don\'t want to perform any text transformations.</p>', ], ], 'TimeWindow' => [ 'base' => '<p>In a <a>GetSampledRequests</a> request, the <code>StartTime</code> and <code>EndTime</code> objects specify the time range for which you want AWS WAF to return a sample of web requests.</p> <p>In a <a>GetSampledRequests</a> response, the <code>StartTime</code> and <code>EndTime</code> objects specify the time range for which AWS WAF actually returned a sample of web requests. AWS WAF gets the specified number of requests from among the first 5,000 requests that your AWS resource receives during the specified time period. If your resource receives more than 5,000 requests during that period, AWS WAF stops sampling after the 5,000th request. In that case, <code>EndTime</code> is the time that AWS WAF received the 5,000th request. </p>', 'refs' => [ 'GetSampledRequestsRequest$TimeWindow' => '<p>The start date and time and the end date and time of the range for which you want <code>GetSampledRequests</code> to return a sample of requests. Specify the date and time in Unix time format (in seconds). You can specify any time range in the previous three hours.</p>', 'GetSampledRequestsResponse$TimeWindow' => '<p>Usually, <code>TimeWindow</code> is the time range that you specified in the <code>GetSampledRequests</code> request. However, if your AWS resource received more than 5,000 requests during the time range that you specified in the request, <code>GetSampledRequests</code> returns the time range for the first 5,000 requests.</p>', ], ], 'Timestamp' => [ 'base' => NULL, 'refs' => [ 'SampledHTTPRequest$Timestamp' => '<p>The time at which AWS WAF received the request from your AWS resource, in Unix time format (in seconds).</p>', 'TimeWindow$StartTime' => '<p>The beginning of the time range from which you want <code>GetSampledRequests</code> to return a sample of the requests that your AWS resource received. You can specify any time range in the previous three hours.</p>', 'TimeWindow$EndTime' => '<p>The end of the time range from which you want <code>GetSampledRequests</code> to return a sample of the requests that your AWS resource received. You can specify any time range in the previous three hours.</p>', ], ], 'URIString' => [ 'base' => NULL, 'refs' => [ 'HTTPRequest$URI' => '<p>The part of a web request that identifies the resource, for example, <code>/images/daily-ad.jpg</code>.</p>', ], ], 'UpdateByteMatchSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'UpdateByteMatchSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'UpdateIPSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'UpdateIPSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'UpdateRuleRequest' => [ 'base' => NULL, 'refs' => [], ], 'UpdateRuleResponse' => [ 'base' => NULL, 'refs' => [], ], 'UpdateSizeConstraintSetRequest' => [ 'base' => NULL, 'refs' => [], ], 'UpdateSizeConstraintSetResponse' => [ 'base' => NULL, 'refs' => [], ], 'UpdateSqlInjectionMatchSetRequest' => [ 'base' => '<p>A request to update a <a>SqlInjectionMatchSet</a>.</p>', 'refs' => [], ], 'UpdateSqlInjectionMatchSetResponse' => [ 'base' => '<p>The response to an <a>UpdateSqlInjectionMatchSets</a> request.</p>', 'refs' => [], ], 'UpdateWebACLRequest' => [ 'base' => NULL, 'refs' => [], ], 'UpdateWebACLResponse' => [ 'base' => NULL, 'refs' => [], ], 'UpdateXssMatchSetRequest' => [ 'base' => '<p>A request to update an <a>XssMatchSet</a>.</p>', 'refs' => [], ], 'UpdateXssMatchSetResponse' => [ 'base' => '<p>The response to an <a>UpdateXssMatchSets</a> request.</p>', 'refs' => [], ], 'WAFDisallowedNameException' => [ 'base' => '<p>The name specified is invalid.</p>', 'refs' => [], ], 'WAFInternalErrorException' => [ 'base' => '<p>The operation failed because of a system problem, even though the request was valid. Retry your request.</p>', 'refs' => [], ], 'WAFInvalidAccountException' => [ 'base' => '<p>The operation failed because you tried to create, update, or delete an object by using an invalid account identifier.</p>', 'refs' => [], ], 'WAFInvalidOperationException' => [ 'base' => '<p>The operation failed because there was nothing to do. For example:</p> <ul> <li>You tried to remove a <code>Rule</code> from a <code>WebACL</code>, but the <code>Rule</code> isn\'t in the specified <code>WebACL</code>.</li> <li>You tried to remove an IP address from an <code>IPSet</code>, but the IP address isn\'t in the specified <code>IPSet</code>.</li> <li>You tried to remove a <code>ByteMatchTuple</code> from a <code>ByteMatchSet</code>, but the <code>ByteMatchTuple</code> isn\'t in the specified <code>WebACL</code>.</li> <li>You tried to add a <code>Rule</code> to a <code>WebACL</code>, but the <code>Rule</code> already exists in the specified <code>WebACL</code>.</li> <li>You tried to add an IP address to an <code>IPSet</code>, but the IP address already exists in the specified <code>IPSet</code>.</li> <li>You tried to add a <code>ByteMatchTuple</code> to a <code>ByteMatchSet</code>, but the <code>ByteMatchTuple</code> already exists in the specified <code>WebACL</code>.</li> </ul>', 'refs' => [], ], 'WAFInvalidParameterException' => [ 'base' => '<p>The operation failed because AWS WAF didn\'t recognize a parameter in the request. For example:</p> <ul> <li>You specified an invalid parameter name.</li> <li>You specified an invalid value.</li> <li>You tried to update an object (<code>ByteMatchSet</code>, <code>IPSet</code>, <code>Rule</code>, or <code>WebACL</code>) using an action other than <code>INSERT</code> or <code>DELETE</code>.</li> <li>You tried to create a <code>WebACL</code> with a <code>DefaultAction</code> <code>Type</code> other than <code>ALLOW</code>, <code>BLOCK</code>, or <code>COUNT</code>.</li> <li>You tried to update a <code>WebACL</code> with a <code>WafAction</code> <code>Type</code> other than <code>ALLOW</code>, <code>BLOCK</code>, or <code>COUNT</code>.</li> <li>You tried to update a <code>ByteMatchSet</code> with a <code>FieldToMatch</code> <code>Type</code> other than HEADER, QUERY_STRING, or URI.</li> <li>You tried to update a <code>ByteMatchSet</code> with a <code>Field</code> of <code>HEADER</code> but no value for <code>Data</code>.</li> </ul>', 'refs' => [], ], 'WAFLimitsExceededException' => [ 'base' => '<p>The operation exceeds a resource limit, for example, the maximum number of <code>WebACL</code> objects that you can create for an AWS account. For more information, see <a href="http://docs.aws.amazon.com/waf/latest/developerguide/limits.html">Limits</a> in the <i>AWS WAF Developer Guide</i>.</p>', 'refs' => [], ], 'WAFNonEmptyEntityException' => [ 'base' => '<p>The operation failed because you tried to delete an object that isn\'t empty. For example:</p> <ul> <li>You tried to delete a <code>WebACL</code> that still contains one or more <code>Rule</code> objects.</li> <li>You tried to delete a <code>Rule</code> that still contains one or more <code>ByteMatchSet</code> objects or other predicates.</li> <li>You tried to delete a <code>ByteMatchSet</code> that contains one or more <code>ByteMatchTuple</code> objects.</li> <li>You tried to delete an <code>IPSet</code> that references one or more IP addresses.</li> </ul>', 'refs' => [], ], 'WAFNonexistentContainerException' => [ 'base' => '<p>The operation failed because you tried to add an object to or delete an object from another object that doesn\'t exist. For example:</p> <ul> <li>You tried to add a <code>Rule</code> to or delete a <code>Rule</code> from a <code>WebACL</code> that doesn\'t exist.</li> <li>You tried to add a <code>ByteMatchSet</code> to or delete a <code>ByteMatchSet</code> from a <code>Rule</code> that doesn\'t exist.</li> <li>You tried to add an IP address to or delete an IP address from an <code>IPSet</code> that doesn\'t exist.</li> <li>You tried to add a <code>ByteMatchTuple</code> to or delete a <code>ByteMatchTuple</code> from a <code>ByteMatchSet</code> that doesn\'t exist.</li> </ul>', 'refs' => [], ], 'WAFNonexistentItemException' => [ 'base' => '<p>The operation failed because the referenced object doesn\'t exist.</p>', 'refs' => [], ], 'WAFReferencedItemException' => [ 'base' => '<p>The operation failed because you tried to delete an object that is still in use. For example: <ul> <li>You tried to delete a <code>ByteMatchSet</code> that is still referenced by a <code>Rule</code>.</li> <li>You tried to delete a <code>Rule</code> that is still referenced by a <code>WebACL</code>.</li> </ul></p>', 'refs' => [], ], 'WAFStaleDataException' => [ 'base' => '<p>The operation failed because you tried to create, update, or delete an object by using a change token that has already been used.</p>', 'refs' => [], ], 'WafAction' => [ 'base' => '<p>For the action that is associated with a rule in a <code>WebACL</code>, specifies the action that you want AWS WAF to perform when a web request matches all of the conditions in a rule. For the default action in a <code>WebACL</code>, specifies the action that you want AWS WAF to take when a web request doesn\'t match all of the conditions in any of the rules in a <code>WebACL</code>. </p>', 'refs' => [ 'ActivatedRule$Action' => '<p>Specifies the action that CloudFront or AWS WAF takes when a web request matches the conditions in the <code>Rule</code>. Valid values for <code>Action</code> include the following:</p> <ul> <li><code>ALLOW</code>: CloudFront responds with the requested object.</li> <li><code>BLOCK</code>: CloudFront responds with an HTTP 403 (Forbidden) status code.</li> <li><code>COUNT</code>: AWS WAF increments a counter of requests that match the conditions in the rule and then continues to inspect the web request based on the remaining rules in the web ACL. </li> </ul>', 'CreateWebACLRequest$DefaultAction' => '<p>The action that you want AWS WAF to take when a request doesn\'t match the criteria specified in any of the <code>Rule</code> objects that are associated with the <code>WebACL</code>.</p>', 'UpdateWebACLRequest$DefaultAction' => NULL, 'WebACL$DefaultAction' => '<p>The action to perform if none of the <code>Rules</code> contained in the <code>WebACL</code> match. The action is specified by the <a>WafAction</a> object.</p>', ], ], 'WafActionType' => [ 'base' => NULL, 'refs' => [ 'WafAction$Type' => '<p>Specifies how you want AWS WAF to respond to requests that match the settings in a <code>Rule</code>. Valid settings include the following:</p> <ul> <li><code>ALLOW</code>: AWS WAF allows requests</li> <li><code>BLOCK</code>: AWS WAF blocks requests</li> <li><code>COUNT</code>: AWS WAF increments a counter of the requests that match all of the conditions in the rule. AWS WAF then continues to inspect the web request based on the remaining rules in the web ACL. You can\'t specify <code>COUNT</code> for the default action for a <code>WebACL</code>.</li> </ul>', ], ], 'WebACL' => [ 'base' => '<p>Contains the <code>Rules</code> that identify the requests that you want to allow, block, or count. In a <code>WebACL</code>, you also specify a default action (<code>ALLOW</code> or <code>BLOCK</code>), and the action for each <code>Rule</code> that you add to a <code>WebACL</code>, for example, block requests from specified IP addresses or block requests from specified referrers. You also associate the <code>WebACL</code> with a CloudFront distribution to identify the requests that you want AWS WAF to filter. If you add more than one <code>Rule</code> to a <code>WebACL</code>, a request needs to match only one of the specifications to be allowed, blocked, or counted. For more information, see <a>UpdateWebACL</a>.</p>', 'refs' => [ 'CreateWebACLResponse$WebACL' => '<p>The <a>WebACL</a> returned in the <code>CreateWebACL</code> response.</p>', 'GetWebACLResponse$WebACL' => '<p>Information about the <a>WebACL</a> that you specified in the <code>GetWebACL</code> request. For more information, see the following topics:</p> <ul> <li><a>WebACL</a>: Contains <code>DefaultAction</code>, <code>MetricName</code>, <code>Name</code>, an array of <code>Rule</code> objects, and <code>WebACLId</code></li> <li><code>DefaultAction</code> (Data type is <a>WafAction</a>): Contains <code>Type</code></li> <li><code>Rules</code>: Contains an array of <code>ActivatedRule</code> objects, which contain <code>Action</code>, <code>Priority</code>, and <code>RuleId</code></li> <li><code>Action</code>: Contains <code>Type</code></li> </ul>', ], ], 'WebACLSummaries' => [ 'base' => NULL, 'refs' => [ 'ListWebACLsResponse$WebACLs' => '<p>An array of <a>WebACLSummary</a> objects.</p>', ], ], 'WebACLSummary' => [ 'base' => '<p>Contains the identifier and the name or description of the <a>WebACL</a>.</p>', 'refs' => [ 'WebACLSummaries$member' => NULL, ], ], 'WebACLUpdate' => [ 'base' => '<p>Specifies whether to insert a <code>Rule</code> into or delete a <code>Rule</code> from a <code>WebACL</code>.</p>', 'refs' => [ 'WebACLUpdates$member' => NULL, ], ], 'WebACLUpdates' => [ 'base' => NULL, 'refs' => [ 'UpdateWebACLRequest$Updates' => '<p>An array of updates to make to the <a>WebACL</a>.</p> <p>An array of <code>WebACLUpdate</code> objects that you want to insert into or delete from a <a>WebACL</a>. For more information, see the applicable data types:</p> <ul> <li><a>WebACLUpdate</a>: Contains <code>Action</code> and <code>ActivatedRule</code></li> <li><a>ActivatedRule</a>: Contains <code>Action</code>, <code>Priority</code>, and <code>RuleId</code></li> <li><a>WafAction</a>: Contains <code>Type</code></li> </ul>', ], ], 'XssMatchSet' => [ 'base' => '<p>A complex type that contains <code>XssMatchTuple</code> objects, which specify the parts of web requests that you want AWS WAF to inspect for cross-site scripting attacks and, if you want AWS WAF to inspect a header, the name of the header. If a <code>XssMatchSet</code> contains more than one <code>XssMatchTuple</code> object, a request needs to include cross-site scripting attacks in only one of the specified parts of the request to be considered a match.</p>', 'refs' => [ 'CreateXssMatchSetResponse$XssMatchSet' => '<p>An <a>XssMatchSet</a>.</p>', 'GetXssMatchSetResponse$XssMatchSet' => '<p>Information about the <a>XssMatchSet</a> that you specified in the <code>GetXssMatchSet</code> request. For more information, see the following topics:</p> <ul> <li><a>XssMatchSet</a>: Contains <code>Name</code>, <code>XssMatchSetId</code>, and an array of <code>XssMatchTuple</code> objects</li> <li><a>XssMatchTuple</a>: Each <code>XssMatchTuple</code> object contains <code>FieldToMatch</code> and <code>TextTransformation</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'XssMatchSetSummaries' => [ 'base' => NULL, 'refs' => [ 'ListXssMatchSetsResponse$XssMatchSets' => '<p>An array of <a>XssMatchSetSummary</a> objects.</p>', ], ], 'XssMatchSetSummary' => [ 'base' => '<p>The <code>Id</code> and <code>Name</code> of an <code>XssMatchSet</code>.</p>', 'refs' => [ 'XssMatchSetSummaries$member' => NULL, ], ], 'XssMatchSetUpdate' => [ 'base' => '<p>Specifies the part of a web request that you want to inspect for cross-site scripting attacks and indicates whether you want to add the specification to an <a>XssMatchSet</a> or delete it from an <code>XssMatchSet</code>.</p>', 'refs' => [ 'XssMatchSetUpdates$member' => NULL, ], ], 'XssMatchSetUpdates' => [ 'base' => NULL, 'refs' => [ 'UpdateXssMatchSetRequest$Updates' => '<p>An array of <code>XssMatchSetUpdate</code> objects that you want to insert into or delete from a <a>XssMatchSet</a>. For more information, see the applicable data types:</p> <ul> <li><a>XssMatchSetUpdate</a>: Contains <code>Action</code> and <code>XssMatchTuple</code></li> <li><a>XssMatchTuple</a>: Contains <code>FieldToMatch</code> and <code>TextTransformation</code></li> <li><a>FieldToMatch</a>: Contains <code>Data</code> and <code>Type</code></li> </ul>', ], ], 'XssMatchTuple' => [ 'base' => '<p>Specifies the part of a web request that you want AWS WAF to inspect for cross-site scripting attacks and, if you want AWS WAF to inspect a header, the name of the header.</p>', 'refs' => [ 'XssMatchSetUpdate$XssMatchTuple' => '<p>Specifies the part of a web request that you want AWS WAF to inspect for cross-site scripting attacks and, if you want AWS WAF to inspect a header, the name of the header.</p>', 'XssMatchTuples$member' => NULL, ], ], 'XssMatchTuples' => [ 'base' => NULL, 'refs' => [ 'XssMatchSet$XssMatchTuples' => '<p>Specifies the parts of web requests that you want to inspect for cross-site scripting attacks.</p>', ], ], 'errorMessage' => [ 'base' => NULL, 'refs' => [ 'WAFDisallowedNameException$message' => NULL, 'WAFInternalErrorException$message' => NULL, 'WAFInvalidOperationException$message' => NULL, 'WAFLimitsExceededException$message' => NULL, 'WAFNonEmptyEntityException$message' => NULL, 'WAFNonexistentContainerException$message' => NULL, 'WAFNonexistentItemException$message' => NULL, 'WAFReferencedItemException$message' => NULL, 'WAFStaleDataException$message' => NULL, ], ], ],];
